########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Monday 26 July 2010 14:44:06 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/Adt/Macro/Vina.py,v 1.1 2010/07/26 21:47:05 jren Exp $
#
# $Id: Vina.py,v 1.1 2010/07/26 21:47:05 jren Exp $
#

from NetworkEditor.macros import MacroNode
from NetworkEditor.macros import MacroNode
class Vina(MacroNode):

    def __init__(self, constrkw={}, name='Vina', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        from Vision.StandardNodes import stdlib
        from WebServices.VisionInterface.WSNodes import wslib
        net.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass

    def afterAddingToNetwork(self):
        masterNet = self.macroNetwork
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        from Vision.StandardNodes import stdlib
        from WebServices.VisionInterface.WSNodes import wslib
        ## building macro network ##
        Vina_30 = self
        from traceback import print_exc
        from Vision.StandardNodes import stdlib
        from WebServices.VisionInterface.WSNodes import wslib
        masterNet.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass
        try:
            ## saving node input Ports ##
            input_Ports_31 = self.macroNetwork.ipNode
            apply(input_Ports_31.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_31=None

        try:
            ## saving node output Ports ##
            output_Ports_32 = self.macroNetwork.opNode
            apply(output_Ports_32.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_32=None

        try:
            ## saving node AutodockVina_Screening_kryptonite_nbcr_net ##
            from NetworkEditor.items import FunctionNode
            AutodockVina_Screening_kryptonite_nbcr_net_33 = FunctionNode(functionOrString='AutodockVina_Screening_kryptonite_nbcr_net', host="http://kryptonite.nbcr.net/opal2", namedArgs={'num_modes': '', 'energy_range': '', 'seed': '', 'receptor': '', 'size_y': '', 'size_z': '', 'out': '', 'log': '', 'urllib': '', 'exhaustiveness': '', 'localRun': False, 'flex': '', 'center_z': '', 'center_x': '', 'center_y': '', 'userlib': '', 'size_x': '', 'config': '', 'filter': '', 'ligand_db': '', 'cpu': '', 'execPath': ''}, constrkw={'functionOrString': "'AutodockVina_Screening_kryptonite_nbcr_net'", 'host': '"http://kryptonite.nbcr.net/opal2"', 'namedArgs': {'num_modes': '', 'energy_range': '', 'seed': '', 'receptor': '', 'size_y': '', 'size_z': '', 'out': '', 'log': '', 'urllib': '', 'exhaustiveness': '', 'localRun': False, 'flex': '', 'center_z': '', 'center_x': '', 'center_y': '', 'userlib': '', 'size_x': '', 'config': '', 'filter': '', 'ligand_db': '', 'cpu': '', 'execPath': ''}}, name='AutodockVina_Screening_kryptonite_nbcr_net', library=wslib)
            self.macroNetwork.addNode(AutodockVina_Screening_kryptonite_nbcr_net_33,217,185)
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['num_modes'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['energy_range'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['seed'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['receptor'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['size_y'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['size_z'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['out'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['log'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['urllib'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['exhaustiveness'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['localRun'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['flex'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['center_z'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['center_x'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['center_y'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['userlib'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['size_x'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['config'].configure, (), {'defaultValue': None, 'required': True})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['filter'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['ligand_db'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['cpu'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['execPath'].configure, (), {'defaultValue': None})
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['num_modes'].widget.configure, (), {'choices': ('1', '2', '3', '4', '5', '6', '7', '8', '9', '10')})
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['num_modes'].widget.set(r"", run=False)
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['energy_range'].widget.configure, (), {'choices': ('1', '2', '3')})
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['energy_range'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['seed'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['receptor'].rebindWidget()
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['receptor'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['receptor'].unbindWidget()
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['size_y'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['size_z'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['out'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['log'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['urllib'].rebindWidget()
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['urllib'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['urllib'].unbindWidget()
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['exhaustiveness'].widget.configure, (), {'choices': ('1', '2', '3', '4', '5', '6', '7', '8')})
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['exhaustiveness'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['localRun'].widget.set(0, run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['flex'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['center_z'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['center_x'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['center_y'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['userlib'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['size_x'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['config'].rebindWidget()
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['config'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['config'].unbindWidget()
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['filter'].rebindWidget()
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['filter'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['filter'].unbindWidget()
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['ligand_db'].widget.configure, (), {'choices': ('sample', 'NCIDS_SC', 'NCI_DS1', 'NCI_DS2', 'human_metabolome', 'chembridge_building_blocks', 'drugbank_nutraceutics', 'drugbank_smallmol', 'asinex', 'fda_approved', 'otava', 'zinc_natural_products')})
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['ligand_db'].widget.set(r"", run=False)
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['cpu'].widget.configure, (), {'choices': ('1', '2')})
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['cpu'].widget.set(r"", run=False)
            AutodockVina_Screening_kryptonite_nbcr_net_33.inputPortByName['execPath'].widget.set(r"", run=False)
            apply(AutodockVina_Screening_kryptonite_nbcr_net_33.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore FunctionNode named AutodockVina_Screening_kryptonite_nbcr_net in network self.macroNetwork"
            print_exc()
            AutodockVina_Screening_kryptonite_nbcr_net_33=None

        try:
            ## saving node PrepareVinaInputs ##
            from Vision.StandardNodes import Generic
            PrepareVinaInputs_34 = Generic(constrkw={}, name='PrepareVinaInputs', library=stdlib)
            self.macroNetwork.addNode(PrepareVinaInputs_34,140,107)
            apply(PrepareVinaInputs_34.addInputPort, (), {'singleConnection': True, 'name': 'receptor_obj', 'cast': True, 'datatype': 'receptor_prepared', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'triangle', 'color': '#009900', 'originalDatatype': 'None'})
            apply(PrepareVinaInputs_34.addInputPort, (), {'singleConnection': True, 'name': 'ligand_obj', 'cast': True, 'datatype': 'LigandDB', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'rect', 'color': '#FFCCFF', 'originalDatatype': 'None'})
            apply(PrepareVinaInputs_34.addOutputPort, (), {'name': 'receptor_file', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(PrepareVinaInputs_34.addOutputPort, (), {'name': 'ligand_lib', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(PrepareVinaInputs_34.addOutputPort, (), {'name': 'filter_file', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            code = """def doit(self, receptor_obj, ligand_obj):
        receptor_file = receptor_obj.path
        filter_file = ligand_obj.filter_file
        ligand_lib = ligand_obj.loc

        if receptor_obj.type == "local":
            if not(os.path.exists(receptor_file)):
                print "ERROR: receptor_file " + receptor_file + " does not exist"
                return '''stop'''
        
	pass
        self.outputData(receptor_file=receptor_file, ligand_lib=ligand_lib, filter_file=filter_file)
## to ouput data on port receptor_file use
## self.outputData(receptor_file=data)
## to ouput data on port ligand_lib use
## self.outputData(ligand_lib=data)
## to ouput data on port filter_file use
## self.outputData(filter_file=data)






"""
            PrepareVinaInputs_34.configure(function=code)
            apply(PrepareVinaInputs_34.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore Generic named PrepareVinaInputs in network self.macroNetwork"
            print_exc()
            PrepareVinaInputs_34=None

        try:
            ## saving node GetMainURLFromList ##
            from WebServices.VisionInterface.WSNodes import GetMainURLFromListNode
            GetMainURLFromList_35 = GetMainURLFromListNode(constrkw={}, name='GetMainURLFromList', library=wslib)
            self.macroNetwork.addNode(GetMainURLFromList_35,217,248)
            apply(GetMainURLFromList_35.inputPortByName['urls'].configure, (), {'defaultValue': None})
            apply(GetMainURLFromList_35.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore GetMainURLFromListNode named GetMainURLFromList in network self.macroNetwork"
            print_exc()
            GetMainURLFromList_35=None

        #self.macroNetwork.run()
        self.macroNetwork.freeze()

        ## saving connections for network Vina ##
        if PrepareVinaInputs_34 is not None and AutodockVina_Screening_kryptonite_nbcr_net_33 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareVinaInputs_34, AutodockVina_Screening_kryptonite_nbcr_net_33, "receptor_file", "receptor", blocking=True
                    , splitratio=[0.48630431331124768, 0.72717758735716731])
            except:
                print "WARNING: failed to restore connection between PrepareVinaInputs_34 and AutodockVina_Screening_kryptonite_nbcr_net_33 in network self.macroNetwork"
        if PrepareVinaInputs_34 is not None and AutodockVina_Screening_kryptonite_nbcr_net_33 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareVinaInputs_34, AutodockVina_Screening_kryptonite_nbcr_net_33, "ligand_lib", "urllib", blocking=True
                    , splitratio=[0.61963739449043087, 0.74955133389937689])
            except:
                print "WARNING: failed to restore connection between PrepareVinaInputs_34 and AutodockVina_Screening_kryptonite_nbcr_net_33 in network self.macroNetwork"
        if PrepareVinaInputs_34 is not None and AutodockVina_Screening_kryptonite_nbcr_net_33 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareVinaInputs_34, AutodockVina_Screening_kryptonite_nbcr_net_33, "filter_file", "filter", blocking=True
                    , splitratio=[0.32670226336274166, 0.25123642944789149])
            except:
                print "WARNING: failed to restore connection between PrepareVinaInputs_34 and AutodockVina_Screening_kryptonite_nbcr_net_33 in network self.macroNetwork"
        if AutodockVina_Screening_kryptonite_nbcr_net_33 is not None and GetMainURLFromList_35 is not None:
            try:
                self.macroNetwork.connectNodes(
                    AutodockVina_Screening_kryptonite_nbcr_net_33, GetMainURLFromList_35, "result", "urls", blocking=True
                    , splitratio=[0.23401196873379349, 0.68593608346615742])
            except:
                print "WARNING: failed to restore connection between AutodockVina_Screening_kryptonite_nbcr_net_33 and GetMainURLFromList_35 in network self.macroNetwork"
        output_Ports_32 = self.macroNetwork.opNode
        if GetMainURLFromList_35 is not None and output_Ports_32 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetMainURLFromList_35, output_Ports_32, "newurl", "new", blocking=True
                    , splitratio=[0.26588001265563421, 0.34355863787969732])
            except:
                print "WARNING: failed to restore connection between GetMainURLFromList_35 and output_Ports_32 in network self.macroNetwork"
        input_Ports_31 = self.macroNetwork.ipNode
        if input_Ports_31 is not None and PrepareVinaInputs_34 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_31, PrepareVinaInputs_34, "new", "receptor_obj", blocking=True
                    , splitratio=[0.59193136382656331, 0.41134942510734418])
            except:
                print "WARNING: failed to restore connection between input_Ports_31 and PrepareVinaInputs_34 in network self.macroNetwork"
        if input_Ports_31 is not None and PrepareVinaInputs_34 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_31, PrepareVinaInputs_34, "new", "ligand_obj", blocking=True
                    , splitratio=[0.29092159940560591, 0.60619808825531374])
            except:
                print "WARNING: failed to restore connection between input_Ports_31 and PrepareVinaInputs_34 in network self.macroNetwork"
        if input_Ports_31 is not None and AutodockVina_Screening_kryptonite_nbcr_net_33 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_31, AutodockVina_Screening_kryptonite_nbcr_net_33, "new", "config", blocking=True
                    , splitratio=[0.24239548372031838, 0.55842775396640953])
            except:
                print "WARNING: failed to restore connection between input_Ports_31 and AutodockVina_Screening_kryptonite_nbcr_net_33 in network self.macroNetwork"
        self.macroNetwork.runOnNewData.value = True

        ## modifying MacroInputNode dynamic ports
        input_Ports_31 = self.macroNetwork.ipNode
        input_Ports_31.outputPorts[1].configure(name='PrepareVinaInputs_receptor_obj')
        input_Ports_31.outputPorts[2].configure(name='PrepareVinaInputs_ligand_obj')
        input_Ports_31.outputPorts[3].configure(name='AutodockVina_Screening_kryptonite_nbcr_net_config')

        ## modifying MacroOutputNode dynamic ports
        output_Ports_32 = self.macroNetwork.opNode
        output_Ports_32.inputPorts[1].configure(singleConnection='auto')
        output_Ports_32.inputPorts[1].configure(name='GetMainURLFromList_newurl')
        ## configure MacroNode input ports
        Vina_30.inputPorts[0].configure(name='PrepareVinaInputs_receptor_obj')
        Vina_30.inputPorts[0].configure(datatype='receptor_prepared')
        Vina_30.inputPorts[1].configure(name='PrepareVinaInputs_ligand_obj')
        Vina_30.inputPorts[1].configure(datatype='LigandDB')
        Vina_30.inputPorts[2].configure(name='AutodockVina_Screening_kryptonite_nbcr_net_config')
        Vina_30.inputPorts[2].configure(datatype='string')
        ## configure MacroNode output ports
        Vina_30.outputPorts[0].configure(name='GetMainURLFromList_newurl')
        Vina_30.outputPorts[0].configure(datatype='string')

        Vina_30.shrink()

        ## reset modifications ##
        Vina_30.resetTags()
        Vina_30.buildOriginalList()



# Authors: Sargis Dallakyan and Rodney Harris 
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/AutoLigandCommand.py,v 1.26 2011/01/06 21:21:14 rhuey Exp $
#
# $Id: AutoLigandCommand.py,v 1.26 2011/01/06 21:21:14 rhuey Exp $
from ViewerFramework.VFCommand import CommandGUI
from Pmv.mvCommand import MVCommand, MVAtomICOM
import Pmw, os, glob, sys, tkMessageBox, Tkinter, subprocess, tkFileDialog
from MolKit.molecule import Atom
from mglutil.gui.InputForm.Tk.gui import InputFormDescr
from mglutil.gui.BasicWidgets.Tk.customizedWidgets import ExtendedSliderWidget
from autostartCommands import menuText
import AutoDockTools 
from mglutil.popen2Threads import SysCmdInThread
import cPickle
from Pmv.pmvPalettes import AtomElements
from MolKit.radii_patterns import AAradii
import copy
AutoLigandPath = os.path.join(AutoDockTools.__path__[0],'AutoLigand.py') 
from MolKit.protein import Protein, Chain, Residue
from MolKit.molecule import Atom, AtomSet
if not os.path.exists(AutoLigandPath):
    sys.stderr.write(AutoLigandPath + "not found\n")

from mglutil.gui.BasicWidgets.Tk.player import Player
from Pmv.moleculeViewer import DeleteAtomsEvent, AddAtomsEvent
from MolKit.molecule import Atom, AtomSet, Molecule
from MolKit.protein import Protein, Chain, Residue

class FloodPlayer(Player):
    def __init__(self, command, file):
        master = command.vf.GUI.ROOT
        self.autoLigandCommand = command.vf.AutoLigandCommand
        self.autoLigandCommand.spheres.Set(visible=1)
        self.autoLigandCommand.halo.Set(visible=1)
        pkl_file = open(file, 'rb')
        self.floods = []
        try:
            data = cPickle.load(pkl_file)
        except Exception, inst:
            print "Error loading ", __file__, "\n", inst
        self.xcent = data[0]
        self.ycent = data[1]
        self.zcent = data[2]
        self.centerx = data[3]
        self.centery = data[4]
        self.centerz = data[5]
        self.spacing = data[6]
        self.centers = []
        data = cPickle.load(pkl_file)
        self.floods.append(data[1])
        try:
            while data:
                data = cPickle.load(pkl_file)
                flood = copy.copy(self.floods[-1])
                for item in data[0]:
                    flood.remove(item)
                for item in data[1]:
                    flood.append(item)
                self.floods.append(flood)
        except EOFError:
            pass
        pkl_file.close()
        fileName = os.path.splitext(os.path.split(file)[-1])[0]
        self.mol = Protein(fileName)
        self.mol.allAtoms = AtomSet([])
        chain = Chain()
        self.residue = Residue(type="UNK")
        chain.adopt(self.residue, setChildrenTop=1)
        self.mol.adopt(chain, setChildrenTop=1)
        self.mol.parser = None
        self.filename = file
        fl = self.floods[0][0]
        x = (fl[1] - self.xcent)*self.spacing + self.centerx
        y = (fl[2] - self.ycent)*self.spacing + self.centery
        z = (fl[3] - self.zcent)*self.spacing + self.centerz
        if fl[4] == 7:
            atomchr = 'P'
            # note, this will color the NA atom pink (the PDB color for Phosphorus)
            radius = AAradii[13][0]
        if fl[4] == 6:
            atomchr = 'S'
            radius = AAradii[13][0]
        if fl[4] == 5:
            atomchr = 'A'
            radius = AAradii[10][0]
        if fl[4] == 4:
            atomchr = 'O'
            radius = AAradii[1][0]
        if fl[4] == 3:
            atomchr = 'N'
            radius = AAradii[4][0]
        if fl[4] == 2:
            atomchr = 'C'
            radius = AAradii[10][0]
        if fl[4] == 1:
            atomchr = 'H'      
            radius = AAradii[15][0]
        a = Atom(atomchr, self.residue, atomchr, top=self.mol)
        a._coords = [[x,y,z]]
        a._charges = {}
        a.hetatm = 1
        a.number = 0
        a.radius = radius
        self.mol.allAtoms = self.residue.atoms
        self.mol = self.autoLigandCommand.vf.addMolecule(self.mol, False)
        self.mol.levels = [Protein, Chain, Residue, Atom]
        self.autoLigandCommand.vf.displayCPK(self.mol, scaleFactor=0.4)
        self.autoLigandCommand.vf.colorByAtomType(self.mol, ['cpk'], log=0)
        self.autoLigandCommand.vf.displayLines(self.mol, negate=True, displayBO=False, lineWidth=2, log=0, only=False)
        self.colorKeys = a.colors.keys()
        maxLen =len(self.floods)-1
        Player.__init__(self, master=master, endFrame=maxLen, maxFrame=maxLen, 
                        titleStr="AutoLigand Flood Player", hasSlider=True)
        try:# withdrew SetAnim button
            self.form.ifd.entryByName['setanimB']['widget'].grid_forget()
            self.form.autoSize()
        except:
            pass
        self.nextFrame(0)
        self.form.root.protocol('WM_DELETE_WINDOW', self.hide_cb)

    def nextFrame(self, id):
        #Player.nextFrame(self, id)
        id = int(id)
        if id == self.currentFrameIndex: return
        if self.hasCounter and self.gui:
            self.form.ent2.delete(0,'end')
            self.form.ent2.insert(0, str(id))
            if self.hasSlider:
                self.form.ifd.entryByName['slider']['widget'].set(id)
        self.currentFrameIndex = int(id)        
        removeAtoms = AtomSet([])
        addAtoms = AtomSet([])
        
        id = int(id)
        flood = self.floods[id]
        centers = []
        materials = []
        radii = []
        prev_coords = self.mol.allAtoms.coords
        lenAtoms = len(prev_coords)
        #self.residue.atoms = AtomSet([])
        index = 0        
        #h = self.hp.heap()
        #print h
        for fl in flood:  
            x = (fl[1] - self.xcent)*self.spacing + self.centerx
            y = (fl[2] - self.ycent)*self.spacing + self.centery
            z = (fl[3] - self.zcent)*self.spacing + self.centerz
            if fl[4] == 7:
                atomchr = 'P'
                # note, this will color the NA atom pink (the PDB color for Phosphorus)
                radius = AAradii[13][0]
            if fl[4] == 6:
                atomchr = 'S'
                radius = AAradii[13][0]
            if fl[4] == 5:
                atomchr = 'A'
                radius = AAradii[10][0]
            if fl[4] == 4:
                atomchr = 'O'
                radius = AAradii[1][0]
            if fl[4] == 3:
                atomchr = 'N'
                radius = AAradii[4][0]
            if fl[4] == 2:
                atomchr = 'C'
                radius = AAradii[10][0]
            if fl[4] == 1:
                atomchr = 'H'      
                radius = AAradii[15][0]
            if not [x,y,z] in prev_coords:
                a = Atom(atomchr, self.residue, atomchr, top=self.mol)
                a._coords = [[x,y,z]]
                a._charges = {}
                a.hetatm = 1
                a.radius = radius
                #a.number = lenAtoms + 1
                addAtoms.append(a)
                lenAtoms += 1
                for key in self.colorKeys:
                    a.colors[key]=AtomElements[atomchr]
                    a.opacities[key]=1.0
            else:
                centers.append([x,y,z])
                            
#            a = Atom(atomchr, self.residue, atomchr, top=self.mol)
#            a._coords = [[x,y,z]]
#            a._charges = {}
#            a.hetatm = 1
#            a.number = index 
#            index += 1
            #aterials.append(AtomElements[atomchr])
            #enters.append([x,y,z])
            #adii.append(radius)
        #self.mol.allAtoms = self.residue.atoms
        #self.mol.geomContainer.geoms['lines'].protected = False
        #for com in self.autoLigandCommand.vf.cmdsWithOnAddObj:
        #    com.onAddObjectToViewer(self.mol)        
        #self.autoLigandCommand.vf.displayCPK(self.mol, scaleFactor=0.1)
        
        halo_centers = []
        for coord in prev_coords:
            if not coord in centers:
                index = prev_coords.index(coord)
                removeAtoms.append(self.mol.allAtoms[index])
        
        
        self.residue.assignUniqIndex() #this is needed to avoid Traceback later on
        self.mol.allAtoms.stringRepr = None #stringRepr can be very large aousing memory errors
        event = AddAtomsEvent(objects=addAtoms)
        #self.autoLigandCommand.vf.dispatchEvent(event)
        self.autoLigandCommand.vf.displayCPK.updateGeom(event)        
        event = DeleteAtomsEvent(objects=removeAtoms)
        #self.autoLigandCommand.vf.dispatchEvent(event)
        self.autoLigandCommand.vf.displayCPK.updateGeom(event)
        for atom in removeAtoms:
            self.residue.atoms.remove(atom)
        if id == self.maxFrame:
            self.autoLigandCommand.halo.Set(visible=0)
        else:
            self.autoLigandCommand.halo.Set(centers=addAtoms.coords, materials=((1,1,0,0.5),), radii=0.4)

        #self.mol.allAtoms = self.residue.atoms

        #self.vf.GUI.VIEWER.Redraw()
        #self.vf.GUI.ROOT.update()        

    def hide_cb(self):
        self.autoLigandCommand.hideGeoms()
        self.form.destroy()

        
class AutoLigandCommand(MVCommand, MVAtomICOM):        
    "GUI for AutoLigand: extends MVCommand, overwrites guiCallback"       
    def __init__(self, func=None):
        MVCommand.__init__(self, func)
        MVAtomICOM.__init__(self)
        self.save = None
        self.showPlayer = False                    
        self.floodFile = None
        
    def onAddCmdToViewer(self):
        from DejaVu.Points import CrossSet
        self.startCross = CrossSet('StartCross', materials=((1.,1.,0),),
                            inheritMaterial=0, protected=True,
                    offset=1.0,lineWidth=5, visible=0, pickable=0,  listed=0)
        self.endCross = CrossSet('EndCross', materials=((0,1,1),),
                            inheritMaterial=0, protected=True,
                    offset=1.0,lineWidth=5, visible=0, pickable=0,  listed=0)

        from DejaVu.IndexedPolygons import IndexedPolygons
        from DejaVu.Box import Box
        from DejaVu.Spheres import Spheres
        from DejaVu import viewerConst
        from DejaVu.bitPatterns import patternList
        from opengltk.OpenGL import GL
        
        face=((0,3,2,1),(3,7,6,2),(7,4,5,6),(0,1,5,4),(1,2,6,5),(0,4,7,3))
        coords=((1,1,-1),(-1,1,-1),(-1,-1,-1),(1,-1,-1),(1,1,1),(-1,1,1),(-1,-1,1),(1,-1,1))
        #new style RGB->
        materials=((0,0,1),(0,1,0),(0,0,1),(0,1,0),(1,0,0),(1,0,0),)
        box=IndexedPolygons('Box', materials=materials, vertices=coords, faces=face,
                            inheritMaterial=0, visible=0, protected=True,  listed=0)
        box.Set(frontPolyMode=GL.GL_LINE)
        box.Set(backPolyMode=GL.GL_LINE)
        box.Set(culling=GL.GL_NONE)
        box.inheritShading=0
        box.shading=GL.GL_FLAT
        box.Set(matBind=viewerConst.PER_PART)
        box.polygonstipple.Set(pattern=patternList[0])
        box.Set(stipplePolygons=1)
        box.transparent=0
        self.box = box
        self.spheres = Spheres('Spheres', visible=0, inheritMaterial=0, radii=(0.3,), protected=True,  listed=0)
        self.halo = Spheres('Halo', visible=0, inheritMaterial=0, radii=(0.5,), protected=True,  listed=0)

                
        from DejaVu.Geom import Geom
        AutoLigand_geoms = Geom("AutoLigand_geoms", shape=(0,0),  listed=0)
        self.vf.GUI.VIEWER.AddObject(AutoLigand_geoms, parent =self.vf.GUI.miscGeom)
        self.vf.GUI.VIEWER.AddObject(self.startCross, parent=AutoLigand_geoms)
        self.vf.GUI.VIEWER.AddObject(self.endCross, parent=AutoLigand_geoms)        
        self.vf.GUI.VIEWER.AddObject(self.box, parent=AutoLigand_geoms)    
        self.vf.GUI.VIEWER.AddObject(self.spheres, parent=AutoLigand_geoms)    
        self.vf.GUI.VIEWER.AddObject(self.halo, parent=AutoLigand_geoms)    
        self.grids = {}
        self.vf.showCitation.citations["AutoLigand"] = """
Please acknowledge the use of the AutoLigand that results
in any published work, including scientific papers, films
and videotapes, by citing the following reference:
Harris R, Olson AJ, Goodsell DS.  Proteins. (2008) 70 1506..
"""
        
    def guiCallback(self, event=None):
        fileList = [] 
        fld_list = glob.glob('*.maps.fld')
        if not fld_list:
            tkMessageBox.showinfo("AutoLigand Info", "AutoLigand requires input AutoGrid maps. \nPlease click OK to select directory containing grid maps.")
            folder = tkFileDialog.askdirectory(title="Select A Folder")
            if folder:
                os.chdir(folder)
                fld_list = glob.glob('*.maps.fld')
            else:
                return
            
        for fld in fld_list:
            fileList.append(fld.split('.')[0])
        entryfield_value = ""
        if fileList:
            fileList.sort()
            entryfield_value = fileList[0]
    
        ifd = InputFormDescr(title="Run AutoLigand")

        ifd.append({'name':"fileName",
                    'widgetType':Pmw.Group,
                    'container':{'fileName':'w.interior()'},
                    'wcfg':{'tag_text':"Base Name for Receptor Map Files"},
                    })       
        ifd.append({'widgetType':Pmw.ComboBox,
                    'name':'FileBaseName',
                    'parent': 'fileName',
                    'tooltip':'FileBaseName = Just the name part from map files (i.e., FileBaseName.C.map)',
                    'wcfg':{
                            'dropdown':1,
                            'scrolledlist_items':fileList,
                            'entryfield_value':entryfield_value,
                            'selectioncommand':self.selectGrid,
                            'labelpos':'w',}
                    })
        ifd.append({'name':"nGroup",
                    'widgetType':Pmw.Group,
                    'container':{'nGroup':'w.interior()'},
                     'tooltip':'Number of heavy atom for ligand or number of fill points to use.',
                    'wcfg':{'tag_text':"Number of "},
                    })          
        ifd.append({'widgetType':Pmw.RadioSelect,
                    'parent':'nGroup',
                    'name':'type',
                    'defaultValue':'Points',
                    'listtext':["Heavy Atoms","Points"],
                    })        
        ifd.append({'widgetType':Pmw.EntryField,
                    'parent':'nGroup',
                    'name':'number',
                    'wcfg':{
                            'labelpos':'w',
                            'value':'100',
                            'validate':{'validator':'integer'}
                            }
                    })

        ifd.append({'widgetType':Pmw.NoteBook,
                                'name':'autoligandNotebook',
                                'container':{ 'Single Fill':"w.page('Single Fill')",
                                                    'Connected Fill':"w.page('Connected Fill')",
                                                    'Scan':"w.page('Scan')"
                                                  },
                                'componentcfg':[ {'name':'Single Fill', 'cfg':{}},
                                                           {'name':'Connected Fill', 'cfg':{}},
                                                           {'name':'Scan','cfg':{}},
                                                   #        {'raisecommand':self.pageChanged}
                                                         ],
                                'wcfg':{'raisecommand':self.pageChanged},
                                'gridcfg':{'sticky':'we'},
                                })        

        #Single Fill
        ifd.append({'name':"StartLoc",
                    'parent':'Single Fill',
                    'widgetType':Pmw.Group,
                    'container':{'StartLoc':'w.interior()'},
                    'wcfg':{'tag_text':"Start Location"},
                    })        
        ifd.append({'widgetType':ExtendedSliderWidget,
                'name':'gridPointsX',
                'parent':'StartLoc',
                'wcfg':{'label':'X: ',
                        'width':190,
                        'immediate':1,
                        'command':self.changeStartCross,
                        'entrypackcfg':{'side':'left'},},
                })        
        ifd.append({'widgetType':ExtendedSliderWidget,
                'name':'gridPointsY',
                'parent':'StartLoc',
                'wcfg':{'label':'Y: ',
                        'width':190,
                        'immediate':1,
                        'command':self.changeStartCross,
                        'entrypackcfg':{'side':'left'},},
                })        
        ifd.append({'widgetType':ExtendedSliderWidget,
                'name':'gridPointsZ',
                'parent':'StartLoc',
                'wcfg':{'label':'Z: ',                    
                        'width':190,
                        'immediate':1,                        
                        'command':self.changeStartCross,                        
                        'entrypackcfg':{'side':'left'},},
                })        

        ifd.append({'name':"output",
                    'widgetType':Pmw.Group,
                    'parent':'Single Fill',
                    'container':{'output':'w.interior()'},
                    'wcfg':{'tag_text':"Output Options"},
                    })        
        ifd.append({'name':'pdbFile',
                    'tooltip':"""Creates PDB_fill_#Nout1.pdb file where #N is the number of fill points.""",
                    'parent':'output',
                    'widgetType':Tkinter.Checkbutton,
                    'defaultValue': 1,
                    'wcfg':{'text':'Create PDB of the Final Fill',
                            'state':'disabled',
                            
                            },
                    'gridcfg':{'sticky':'w'}
                    })        

        ifd.append({'name':'showProgress',
                    'parent':'output',
                    'tooltip':"""Save intermediate results in a file and open flood player when AutoLigand finishes.""",
                    'widgetType':Tkinter.Checkbutton,
                    'defaultValue': 0,
                    'wcfg':{'text':'Save Intermediate Results for Movie',
                            'variable':Tkinter.IntVar(),
                            },
                    'gridcfg':{'sticky':'w'}
                    })        
        #Connected Fill
        ifd.append({'widgetType':Tkinter.Label,
                'name':'label',
                'parent':'Connected Fill',
                'wcfg':{'text':'Select End Location for Connected Fill'}
                        })   
        ifd.append({'name':"EndLoc",
                    'parent':'Connected Fill',
                    'widgetType':Pmw.Group,
                    'container':{'EndLoc':'w.interior()'},
                    'wcfg':{'tag_text':"End Location"},
                    })        
        ifd.append({'widgetType':ExtendedSliderWidget,
                'name':'gridPointsXEnd',
                'parent':'EndLoc',
                'wcfg':{'label':'X: ',
                        'width':190,
                        'immediate':1,
                        'command':self.changeEndCross,
                        'entrypackcfg':{'side':'left'},},
                })        
        ifd.append({'widgetType':ExtendedSliderWidget,
                'name':'gridPointsYEnd',
                'parent':'EndLoc',
                'wcfg':{'label':'Y: ',
                        'width':190,
                        'immediate':1,
                        'command':self.changeEndCross,
                        'entrypackcfg':{'side':'left'},},
                })        
        ifd.append({'widgetType':ExtendedSliderWidget,
                'name':'gridPointsZEnd',
                'parent':'EndLoc',
                'wcfg':{'label':'Z: ',                    
                        'width':190,
                        'immediate':1,                        
                        'command':self.changeEndCross,                        
                        'entrypackcfg':{'side':'left'},},
                })
                
        #Connected Fill
#        ifd.append({'widgetType':Tkinter.Label,
#                'name':'label',
#                'parent':'Scan',
#                'wcfg':{'text':"""Results from the Scan mode will 
#be available under\n"""+os.getcwd()}
#                        })   
        ifd.append({'widgetType':Pmw.EntryField,
                    'parent':'Scan',                    
                    'name':'nFills',
                    'wcfg':{'label_text':"Number of Fills:",
                            'labelpos':'w',
                            'value':'10',
                            'validate':{'validator':'integer'}
                            }
                    })
                
        def initselect(arg):
            self.selectGrid(entryfield_value)

        self.ifd = ifd
        self.save = self.vf.ICmdCaller.commands.value["Shift_L"]
        self.vf.setICOM(self, modifier="Shift_L", topCommand=0)
        self.vf.setIcomLevel( Atom )
        self.endCross.Set(visible=0)
        val = self.vf.getUserInput(ifd,modal=0, blocking=1,
                                   initFunc=initselect)
        if self.save:
            self.vf.setICOM(self.save, modifier="Shift_L", topCommand=0)
            self.save = None
       # import pdb;pdb.set_trace()
        if val: 
            if not val['FileBaseName'][0]:
                msg = "AutoGrid files are missing.\n"
                msg += "Please generate grid maps. AutoLigand requires input AutoGrid maps."
                tkMessageBox.showerror("Error!", msg)
                return
            selection =  self.ifd.entryByName['autoligandNotebook']['widget'].getcurselection()
            cmdString = [sys.executable, AutoLigandPath]
            cmdString.append('-r')
            cmdString.append(val['FileBaseName'][0])
            self.fileBaseName = val['FileBaseName'][0]
            if val['type'] == 'Points':
                cmdString.append('-p')
                cmdString.append(str(val['number']))
            else:
                cmdString.append('-a')
                cmdString.append(str(val['number']))    
                val['number'] = 6*int(val['number'])                

            if selection in ['Single Fill','Connected Fill']:
                cmdString.append('-x')
                cmdString.append(str(val['gridPointsX']))
                cmdString.append('-y')
                cmdString.append(str(val['gridPointsY']))
                cmdString.append('-z')
                cmdString.append(str(val['gridPointsZ']))
                if selection == 'Connected Fill':
                    cmdString.append('-i')
                    cmdString.append(str(val['gridPointsXEnd']))
                    cmdString.append('-j')
                    cmdString.append(str(val['gridPointsYEnd']))
                    cmdString.append('-k')
                    cmdString.append(str(val['gridPointsZEnd']))
                if os.name == 'nt': #sys.platform == "win32":
                    self.cmdTxt = subprocess.list2cmdline(cmdString)
                else:
                    self.cmdTxt = ' '.join(cmdString)            
                if val['showProgress']:
                    self.cmdTxt += " -m"
                    self.showPlayer = True
                else:
                    self.showPlayer = False
                self.cmd = SysCmdInThread(self.cmdTxt, shell=True)
                self.cmd.start()
                self.checkResults()            
                self.N_of_pts = val['number']
            elif selection == "Scan":
                cmdString.append('-f')
                cmdString.append(str(val['nFills']))
                if os.name == 'nt': #sys.platform == "win32":
                    self.cmdTxt = subprocess.list2cmdline(cmdString)
                else:
                    self.cmdTxt = ' '.join(cmdString)            
                    self.cmdTxt += ' &'#run in a background
                
                subprocess.Popen(self.cmdTxt, shell=True)
                tkMessageBox.showinfo("Success!", """AutoLigand launched successfully.""")                              
        else:
            self.hideGeoms()
            
    def pageChanged(self, name):
        if name == 'Single Fill':
            self.startCross.Set(visible=1)
        elif name == 'Connected Fill':
            self.endCross.Set(visible=1)
        else:
            self.startCross.Set(visible=0)
            self.endCross.Set(visible=0)            
    
    def selectGrid(self, value):
        if not value:
            return
        lines = open(value+".maps.fld").readlines()
        if not lines: return
        for line in lines:
            if line.startswith("#SPACING"):
                spacing = float(line.split()[-1])
            if line.startswith("#NELEMENTS"):
                tmp = line.split()
                dimX = int(tmp[1])
                dimY = int(tmp[2])
                dimZ = int(tmp[3])
            if line.startswith("#CENTER"):
                tmp = line.split()
                centerX = float(tmp[1])
                centerY = float(tmp[2])
                centerZ = float(tmp[3])
        #this variables are the same used in AutoLigand.py
        self.xcent = int(dimX/2)
        self.ycent = int(dimY/2)
        self.zcent = int(dimZ/2)        
        self.centerx = centerX
        self.centery = centerY
        self.centerz = centerZ
        self.spacing = spacing
        c = [centerX,centerY,centerZ]
        xlen = round(spacing*dimX, 4)
        ylen = round(spacing*dimY, 4)
        zlen = round(spacing*dimZ, 4)  
        self.minX = c[0]-xlen*0.5
        self.maxX = c[0]+xlen*0.5
        if self.grids.has_key(value):
            centerX = self.grids[value][0]
            centerY = self.grids[value][1]
            centerZ = self.grids[value][2]

        self.ifd.entryByName['gridPointsX']['widget'].configure(minval=self.minX,
                                                                maxval=self.maxX, )
        self.ifd.entryByName['gridPointsXEnd']['widget'].configure(minval=self.minX,
                                                                maxval=self.maxX, )
        
        self.minY = c[1]-ylen*0.5
        self.maxY = c[1]+ylen*0.5

        self.ifd.entryByName['gridPointsY']['widget'].configure(minval=self.minY,
                                                                maxval=self.maxY, )
        self.ifd.entryByName['gridPointsYEnd']['widget'].configure(minval=self.minY,
                                                                maxval=self.maxY, )
        self.minZ = c[2]-zlen*0.5
        self.maxZ = c[2]+zlen*0.5
        self.ifd.entryByName['gridPointsZ']['widget'].configure(minval=self.minZ,
                                                                maxval=self.maxZ, )
        self.ifd.entryByName['gridPointsZEnd']['widget'].configure(minval=self.minY,
                                                                maxval=self.maxY, )
        
        self.startCross.Set(vertices=((centerX,centerY,centerZ),))        
        self.ifd.entryByName['gridPointsX']['widget'].set(centerX)
        self.ifd.entryByName['gridPointsY']['widget'].set(centerY)
        self.ifd.entryByName['gridPointsZ']['widget'].set(centerZ)
        self.ifd.entryByName['gridPointsXEnd']['widget'].set(centerX+12)
        self.ifd.entryByName['gridPointsYEnd']['widget'].set(centerY+12)
        self.ifd.entryByName['gridPointsZEnd']['widget'].set(centerZ+12)
        self.endCross.Set(vertices=((centerX+12,centerY+12,centerZ+12),))

        pts = [     (self.maxX, self.maxY, self.minZ),
                    (self.minX, self.maxY, self.minZ),
                    (self.minX, self.minY, self.minZ),
                    (self.maxX, self.minY, self.minZ),
                    (self.maxX, self.maxY, self.maxZ),
                    (self.minX, self.maxY, self.maxZ),
                    (self.minX, self.minY, self.maxZ),
                    (self.maxX, self.minY, self.maxZ)
                    ]
         
        self.box.Set(visible=1)
        #self.startCross.Set(visible=1)
        self.box.vertexSet.vertices.array[:] = pts
        self.box.RedoDisplayList()
        self.vf.GUI.VIEWER.Normalize_cb()
        self.vf.GUI.VIEWER.Redraw()
        
    def changeStartCross(self, val):
        centerX = self.ifd.entryByName['gridPointsX']['widget'].get()
        centerY = self.ifd.entryByName['gridPointsY']['widget'].get()
        centerZ = self.ifd.entryByName['gridPointsZ']['widget'].get()
        grid = self.ifd.entryByName['FileBaseName']['widget'].get()
        if grid:
            self.grids[grid] = [centerX,centerY,centerZ]
        self.startCross.Set(visible=1)
        self.startCross.Set(vertices=((centerX,centerY,centerZ),))
        self.vf.GUI.VIEWER.Redraw()   

    def changeEndCross(self, val):
        centerX = self.ifd.entryByName['gridPointsXEnd']['widget'].get()
        centerY = self.ifd.entryByName['gridPointsYEnd']['widget'].get()
        centerZ = self.ifd.entryByName['gridPointsZEnd']['widget'].get()
        grid = self.ifd.entryByName['FileBaseName']['widget'].get()
        #self.endCross.Set(visible=1)
        self.endCross.Set(vertices=((centerX,centerY,centerZ),))
        self.vf.GUI.VIEWER.Redraw()   

    def checkResults(self):
        """Checks the queue for results until we get one"""
        if self.cmd.ok.configure()['state'][-1] == 'normal':
            if self.showPlayer:
                self.openPklData()
            else:
                molName = "FILL_"+str(self.N_of_pts)+"out1"
                if os.path.exists(molName+".pdb"):
                    self.vf.readMolecule(molName+".pdb")
                    self.vf.displaySticksAndBalls(molName, cradius=0.0, sticksBallsLicorice="Sticks and Balls")
                    self.vf.displayLines(molName, negate=True, displayBO=False)
                    self.vf.colorByAtomType(molName, ['sticks', 'balls'])
                self.vf.GUI.ROOT.after(2050, self.hideGeoms)
            return
        self.vf.GUI.ROOT.after(100, self.checkResults)
        
    def hideGeoms(self):
        self.box.Set(visible=0)
        self.startCross.Set(visible=0)
        self.endCross.Set(visible=0)        
        self.spheres.Set(visible=0)
        self.halo.Set(visible=0)
        
    def __call__(self, atom, **kw):
        if not atom:
            return 'ERROR'
        atoms = self.vf.expandNodes(atom)
        if not atoms:
            return 'ERROR'
        atoms = atoms.findType(Atom)
        if not atoms:
            return 'ERROR'
        apply( self.doitWrapper, (atoms,), kw)

    def doit(self, atoms=None):
        if len(atoms)==0: return 
        atom = atoms[0]
        if self.minX < atom.coords[0] > self.maxX:
            return
        if self.minY < atom.coords[1] > self.maxY:
            return
        if self.minZ < atom.coords[2] > self.maxZ:
            return
        
        selection =  self.ifd.entryByName['autoligandNotebook']['widget'].getcurselection()
        if selection ==  "Single Fill":
            self.ifd.entryByName['gridPointsX']['widget'].set(atom.coords[0])
            self.ifd.entryByName['gridPointsY']['widget'].set(atom.coords[1])
            self.ifd.entryByName['gridPointsZ']['widget'].set(atom.coords[2])
    #        self.startCross.Set(visible=1)
            self.startCross.Set(vertices=((atom.coords[0], atom.coords[1], atom.coords[2]),))
        elif selection ==  "Connected Fill":
            self.ifd.entryByName['gridPointsXEnd']['widget'].set(atom.coords[0])
            self.ifd.entryByName['gridPointsYEnd']['widget'].set(atom.coords[1])
            self.ifd.entryByName['gridPointsZEnd']['widget'].set(atom.coords[2])
            self.endCross.Set(vertices=((atom.coords[0], atom.coords[1], atom.coords[2]),))
            
        self.vf.GUI.VIEWER.Redraw()                          
         
        
    def openPklData(self):
        self.vf.AutoLigandMovieCommand(self.fileBaseName+'_flood.pkl')
            
AutoLigandCommandGUI = CommandGUI()
AutoLigandCommandGUI.addMenuCommand('menuRoot', 'Compute', 'Run AutoLigand...', 
                                    cascadeName="AutoLigand")


class OpenMovieCommand(MVCommand):        
    "GUI that opens saved movie of fill file."       
    def __init__(self, func=None):
        MVCommand.__init__(self, func)
        self.floodFile = None


    def guiCallback(self):
        file = self.vf.askFileOpen(types=[('Saved Flood File', '*.pkl'),('All Files', '*')],
                                   title='Open Saved Flood File')        
        if file:
            self.doitWrapper(file)

    def doit(self, file):
        FloodPlayer(self, file)
    
    
OpenMovieCommandGUI = CommandGUI()
OpenMovieCommandGUI.addMenuCommand('menuRoot', 'Compute', 'Open Saved Movie...', 
                                    cascadeName="AutoLigand")

commandList  = [{'name':'AutoLigandCommand','cmd':AutoLigandCommand(),'gui':AutoLigandCommandGUI},
                {'name':'AutoLigandMovieCommand','cmd':OpenMovieCommand(),'gui':OpenMovieCommandGUI}]

def initModule(viewer):
    for _dict in commandList:
        viewer.addCommand(_dict['cmd'],_dict['name'],_dict['gui'])




#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/prepare_dpf_vif.py,v 1.4 2012/03/01 23:09:58 rhuey Exp $
#

import string
import os.path
from math import floor
from MolKit import Read
from AutoDockTools.DockingParameters import DockingParameters, DockingParameter42FileMaker, genetic_algorithm_list, \
                genetic_algorithm_local_search_list4, local_search_list4,\
                simulated_annealing_list4
                


 

def usage():
    print "Usage: prepare_dpf_vif.py -l pdbqt_file  -i template_filename"
    print "    -l ligand_filename"
    print "    -i template_filename"
    print
    print "Optional parameters:"
    print "    [-v] verbose output"
    print "    [-o] output dpf_filename"
    print
    print "Prepare a docking parameter file (DPF) for docking constrained models with AutoDock4."
    print

    
if __name__ == '__main__':
    import getopt
    import sys

    #print "    [-C] use two atoms with autodock_element LS for setting about"
    #    opt_list, args = getopt.getopt(sys.argv[1:], 'sLShvl:r:i:o:x:p:k:eC')
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'vl:i:o:h')
    except getopt.GetoptError, msg:
        print 'prepare_dpf_vif.py: %s' % msg
        usage()
        sys.exit(2)

    ligand_filename = None
    template_filename = None
    dpf_filename = None
    verbose = None
    for o, a in opt_list:
        if o in ('-v', '--v'):
            verbose = 1
            if verbose: print 'verbose output'
        if o in ('-l', '--l'):   #ligand filename
            ligand_filename = a
            if verbose: print 'ligand_filename =', ligand_filename
        if o in ('-i', '--i'):   #input reference
            template_filename = a
            if verbose: print 'template_filename =', template_filename
        if o in ('-o', '--o'):   #output filename
            dpf_filename = a
            if verbose: print 'output dpf_filename =', dpf_filename
        if o in ('-h', '--'):
            usage()
            sys.exit()


    if (not ligand_filename) or (not template_filename):
        print "prepare_dpf_vif.py: ligand filename and template filename"
        print "                    must be specified."
        usage()
        sys.exit()


    if template_filename is not None:  #setup values by reading dpf
        tptr = open(template_filename)
        TEMPLATE_DPFlines = tptr.readlines()
        tptr.close()
    #check for format, determine center from LS atoms
    ligand = Read(ligand_filename)
    if not len(ligand):
        print " problem reading ligand ", ligand_filename
        sys.exit()
    lig = ligand[0]
    lig_types = set(lig.allAtoms.autodock_element)
    if "LS" not in lig_types: #verify format for constrained docking 
        print "@@no LS atoms found in ligand ", ligand_filename, "@@"
        sys.exit()

    found_cen_res = False
    LS_ats = lig.allAtoms.get(lambda x: x.autodock_element=='LS')
    if not len(LS_ats):
        print ligand_filename, " does not have any 'LS' atoms"
        raise 'improperly formatted ligand file' #@@ just exit??
    if len(LS_ats):
        cen_res=""
        len_ls_ats = len(LS_ats)
        parent_indices= map(int, LS_ats.parent.number)
        if verbose: print "parent_indices=", parent_indices
        first_parent_index =  int(parent_indices[0])
        if verbose: print "first parent_index is ", first_parent_index
        mid_index = int(len_ls_ats/2.)
        if verbose: print "mid_index=", mid_index
        if len_ls_ats%2==1:
            mid_index = int(floor(len_ls_ats/2.))
            if verbose: print "NOW mid_index=", mid_index
        cen_res_number = first_parent_index+mid_index
        if verbose: print "cen_res_number = ", cen_res_number
        cen_res = lig.chains.residues.get(lambda x: int(x.number)==cen_res_number)
        if len(cen_res):
            cen_at = cen_res[0].atoms.get(lambda x: x.autodock_element=='RP')[0]
            if verbose: print 'cen_at coords= ', cen_at.coords, ' cen_at.parent=', cen_at.parent.full_name()
            about = cen_at.coords
            if verbose: print "ABOUT= ", about
            found_cen_res = True
            about_value = cen_at.coords
            if verbose: print "about is ", dm.dpo['about']['value'] 
        else:
            raise ligand_filename+ ':problem finding center residue!'
        
    #OUTPUT with new about value
    #dm.write_dpf(dpf_filename, parameter_list, pop_seed)
    if dpf_filename is None:
        dpf_filename = "3ir2mod_" + lig.name + ".dpf" 
        print "set dpf_filename to ", dpf_filename
    optr = open(dpf_filename, 'w')
    for l in TEMPLATE_DPFlines: 
        if l.find('about')==0:
            new_l = 'about  %5.2f %5.2f %5.2f             # small molecule center\n'%(about[0], about[1], about[2])
            print "wrote new about:" + new_l
            optr.write(new_l)
        elif l.find('move')==0:
            new_l = 'move  ' + lig.parser.filename +    "               # small molecule\n"
            optr.write(new_l)
            print "wrote new move:" + new_l
        else:
            optr.write(l)
    optr.close()
    
# To execute this command type:
# prepare_dpf_vif.py -l pdbqt_file  -o output_dpf_filename -i template dpf_filename 




#########################################################################
#
# Date: Nov 2001 Authors: Michel Sanner
#
#    sanner@scripps.edu
#
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Michel Sanner and TSRI
#
#########################################################################

from NetworkEditor.items import NetworkNode

from AutoDockTools.VisionInterface.Adt.receptor import receptor

import os

class PreparedStructureBrowser(NetworkNode):
    """
    Allows the user to browse a structure prepared pdbqt structure.
    """
    
    def __init__(self, name='StructureBrowser', **kw):
        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )

        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )
        ip = self.inputPortsDescr
        ip.append(datatype='string', name='prepared_structure_file')

        filetypes = [('All supported files', '*.pdbqt')]

        self.widgetDescr['prepared_structure_file'] = {
            'class':'NEEntryWithFileBrowser', 'master':'node', 'width':20,
            'filetypes':filetypes,
            'initialValue':'', 'labelCfg':{'text':'Prepared Structure file: '}
            }

        op = self.outputPortsDescr
        op.append(datatype='receptor_prepared', name='receptor_obj')

        code = """def doit(self, prepared_structure_file):
    import os

    receptor_file = os.path.abspath(prepared_structure_file)

    if not(os.path.exists(prepared_structure_file)):
        print "ERROR: prepared structure file " + prepared_structure_file + " does not exist!"
        return 'stop'

    receptor_obj = receptor(prepared_structure_file)

    self.outputData(receptor_obj=receptor_obj)
"""
        self.setFunction(code)



## Automatically adapted for numpy.oldnumeric Jul 23, 2007 by 

#############################################################################
# 
# Histogram class: 
# Written by Konrad Hinsen <hinsen@cnrs-orleans.fr> 
# last revision: 1999-7-6
#
# HistogramRI class written by Ruth Huey
# HistogramRI adds a reverse Index to Histogram class 
#
#############################################################################


import numpy.oldnumeric as Numeric; N = Numeric

class Histogram:

    """Histogram in one variable

    Constructor: Histogram(|data|, |bins|, |range|=None)

    Arguments:

    |data| -- a sequence of data points

    |bins| -- the number of bins into which the data is to be sorted

    |range| -- a tuple of two values, specifying the lower and
               the upper end of the interval spanned by the bins.
               Any data point outside this interval will be ignored.
               If no range is given, the smallest and largest
               data values are used to define the interval.

    The number of points in a bin can be obtained by indexing the
    histogram with the bin number. Application of len() yields the
    number of bins. A histogram thus behaves like a sequence of
    numbers.
    """

    def __init__(self, data, nbins, range=None):
        if range is None:
            self.min = N.minimum.reduce(data)
            self.max = N.maximum.reduce(data)
        else:
            self.min, self.max = range
        self.min = self.min+0.
        self.max = self.max+0.
        self.bin_width = (self.max-self.min)/nbins
        if self.bin_width==0:
            print 'range is 0 so set bin_width to 1.'
            self.bin_width = 1.
        self.array = N.zeros((nbins, 2), N.Float)
        self.array[:, 0] = self.min + self.bin_width*(N.arange(nbins)+0.5)
        self.addData(data)

    def __len__(self):
        return self.array.shape[0]

    def __getitem__(self, index):
        return self.array[index]

    def __getslice__(self, first, last):
        return self.array[first:last]

    def addData(self, data):
        """Add the values in |data| (a sequence of numbers) to the
        originally supplied data. Note that this does not affect the
        default range of the histogram, which is fixed when the
        histogram is created.
        """
        n = (len(data)+999)/1000
        for i in range(n):
            self._addData(data[1000*i:1000*(i+1)])

    def _addData(self, data):
        data = N.array(data, N.Float)
        data = N.repeat(data, N.logical_and(N.less_equal(data, self.max),
                                            N.greater_equal(data, self.min)))
        data = N.floor((data - self.min)/self.bin_width).astype(N.Int)
        self.rIdata = data
        nbins = self.array.shape[0]
        histo = N.add.reduce(N.equal(N.arange(nbins)[:,N.NewAxis], data), -1)
        histo[-1] = histo[-1] + N.add.reduce(N.equal(nbins, data))
        self.array[:, 1] =  self.array[:, 1] + histo

    def normalize(self, norm=1.):
        "Scales all counts by the same factor such that their sum is |norm|."
        self.array[:, 1] = norm*self.array[:, 1]/N.add.reduce(self.array[:, 1])


class HistogramRI(Histogram):
    """ This class is based on Histogram class developed by K.Hinsen. It adds
    a method, 'createReverseIndex', which builds a list of data points in each
    bin"""

    def __init__(self, data, nbins, range=None):
        Histogram.__init__(self, data, nbins, range)
        self.data = data

    
    def createReverseIndex(self):
        #first build the data in the correct form:
        N = Numeric
        nbins = self.array.shape[0]
        data = N.array(self.data, N.Float)
        data = N.repeat(data, N.logical_and(N.less_equal(data, self.max),
                    N.greater_equal(data, self.min)))
        data = N.floor((data-self.min)/self.bin_width).astype(N.Int)
        self.cRI_data = data
        #check for pt outside of nbins
        #sometimes max point falls outside of right-most bin
        #first stuff works with python2.0 second with both
        try:
            self.cRI_data = N.putmask(data, N.greater_equal(data,nbins),nbins-1)
        except:
            for i in range(data.shape[0]):
                if data[i]>=nbins: data[i] = nbins-1
        self.reverseIndex = []
        for i in range(nbins):
            newentry = N.nonzero(N.equal(data, i)).tolist()
            #print i,'th entry =', newentry
            self.reverseIndex.append(newentry)
            

if __name__ == '__main__':


    data = N.arange(500)
    #data = N.arange(5000)
    #h = Histogram(data, 10)
    hRI = HistogramRI(data, 10)



#############################################################################
#
# Author: Ruth HUEY, Michel F. SANNER
#
# Copyright: M. Sanner TSRI 2000
#
#############################################################################

#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/autotors3Commands.py,v 1.3 2009/02/10 17:44:05 rhuey Exp $
#
# $Id: autotors3Commands.py,v 1.3 2009/02/10 17:44:05 rhuey Exp $
#
#
#
#
#
#
#
"""
This Module is used to setup files for autodock3 calculations.
"""

import Tkinter

from ViewerFramework.VFCommand import CommandGUI

from AutoDockTools.autotorsCommands import rootSph, markSph,\
menuText, AtorsMoleculeChooser, MAXTORS, AdtSetMode,\
AtorsReader, Ators4MoleculeChooser, Ators4Reader, AtorsRefWriter, \
RigidMolecule, RigidMolecule4, AUTOTORSWriter, AUTOTORS4Writer, \
MarkRoot, SelectRoot, SetTorsionNumberGUICommand, SetTorsionNumber, \
AutoRoot, SetRotatableBonds, DefiningRotatableBonds, SetBondRotatableFlag,\
CheckAromatic, StopCheckAromatic, SetCarbonNames, ChangeAromaticCutOff, \
TogglerootSphere, AutoAutoTors, StopAutoTors, AtorsInit, AtorsInitMol, \
ProcessCharges, ProcessBonds, rootSph, markSph, check_autotors_geoms,\
MAXTORS, menuText, warningText, checkMolCharges,\
autoMergeNPHS, set_autoMergeNPHS



#???Set RotatableBonds???
from AutoDockTools.autotorsCommands import AtorsMoleculeChooser


AtorsMoleculeChooserGUI=CommandGUI()
AtorsMoleculeChooserGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['Choose Molecule'], cascadeName = menuText['Input Molecule'])


AtorsReaderGUI = CommandGUI()
AtorsReaderGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['Read Molecule'], cascadeName = menuText['Input Molecule'])


AtorsRefWriterGUI = CommandGUI()
AtorsRefWriterGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['Ref Molecule'], cascadeName = menuText['Input Molecule'])


RigidMoleculeGUI = CommandGUI()
RigidMoleculeGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['Rigid Molecule'], cascadeName = menuText['Input Molecule'])


AUTOTORSWriterGUI=CommandGUI()
AUTOTORSWriterGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['WritePDBQMB'], cascadeName = menuText['WriteMB'])


MarkRootGUI=CommandGUI()
MarkRootGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['SRA1'], cascadeName = menuText['DefineRigidRootMB'])


SelectRootGUI=CommandGUI()
SelectRootGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['ByPicking'], cascadeName = menuText['DefineRigidRootMB'])


SetTorsionNumberGUICommandGUI=CommandGUI()
SetTorsionNumberGUICommandGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
 menuText['SetTorsionNumber'], cascadeName = menuText['DefineRigidRootMB'] )


AutoRootGUI=CommandGUI()
AutoRootGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['Automatically'], cascadeName = menuText['DefineRigidRootMB'])


DefiningRotatableBondsGUI = CommandGUI()
DefiningRotatableBondsGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['DefineRotatableBonds'], cascadeName = menuText['DefineRigidRootMB'])


CheckAromaticGUI = CommandGUI()
CheckAromaticGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['RenameAromaticCarbons'], cascadeName = menuText['AromaticCarbonsMB'])



StopCheckAromaticGUI = CommandGUI()
StopCheckAromaticGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['RestoreAliphaticCarbons'], cascadeName = menuText['AromaticCarbonsMB'])



SetCarbonNamesGUI = CommandGUI()
SetCarbonNamesGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['SetCarbonNames'], cascadeName = menuText['AromaticCarbonsMB'])



ChangeAromaticCutOffGUI=CommandGUI()
ChangeAromaticCutOffGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['ChangeAromaticityCriteria'], cascadeName = menuText['AromaticCarbonsMB'])



TogglerootSphereGUI=CommandGUI()
TogglerootSphereGUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'],\
menuText['ShowAutotorsRootSphMB'], cascadeName = menuText['DefineRigidRootMB'])


AutoAutoTors3GUI=CommandGUI()
AutoAutoTors3GUI.addMenuCommand('AutoTools3Bar', menuText['AutoTorsMB'], \
menuText['AutomaticAutotorsSetupMB'], cascadeName = menuText['Input Molecule'])


commandList = [
    
    {'name':'AD3tors_readLigand','cmd':AtorsReader(),
        'gui':AtorsReaderGUI},
    {'name':'AD3tors_chooseLigand','cmd':AtorsMoleculeChooser(),
        'gui':AtorsMoleculeChooserGUI},
    {'name':'AD3tors_rigidLigand','cmd':RigidMolecule(),
        'gui':RigidMoleculeGUI},
    {'name':'AD3tors_automaticLigandFormatting','cmd':AutoAutoTors(),
        'gui':AutoAutoTors3GUI},
#    {'name':'AD3tors_writeRef','cmd':AtorsRefWriter(),
#        'gui':AtorsRefWriterGUI},
    {'name':'AD3tors_setRoot','cmd':SelectRoot(),'gui':SelectRootGUI},
    {'name':'AD3tors_autoRoot','cmd':AutoRoot(),'gui':AutoRootGUI},
#    {'name':'AD3tors_addChainToRootGC','cmd':AddChainToRootGUICommand(),
#        'gui':AddChainToRootGUICommandGUI},
#    {'name':'AD3tors_addChainToRoot','cmd':AddChainToRoot(),'gui':None},
#    {'name':'AD3tors_removeChainFromRootGC','cmd':RemoveChainFromRootGUICommand(),
#        'gui':RemoveChainFromRootGUICommandGUI},
#    {'name':'AD3tors_removeChainFromRoot','cmd':RemoveChainFromRoot(),'gui':None},
    {'name':'AD3tors_markRoot','cmd':MarkRoot(),'gui':MarkRootGUI},
    {'name':'AD3tors_showRootSphere','cmd':TogglerootSphere(),
        'gui':TogglerootSphereGUI},

    {'name':'AD3tors_defineRotBonds', 'cmd':DefiningRotatableBonds(),
         'gui':DefiningRotatableBondsGUI },
    {'name':'AD3tors_limitTorsionsGC','cmd':SetTorsionNumberGUICommand(),
        'gui':SetTorsionNumberGUICommandGUI},
##    {'name':'AD3tors_changePlanarCarbonsToA','cmd':CheckAromatic(),
##        'gui':CheckAromaticGUI},
##    {'name':'AD3tors_changeAromaticCarbonsToC','cmd':StopCheckAromatic(),
##        'gui':StopCheckAromaticGUI},
    {'name':'AD3tors_setCarbonNames','cmd':SetCarbonNames(),
        'gui':SetCarbonNamesGUI},
    {'name':'AD3tors_changePlanarityCriteria','cmd':ChangeAromaticCutOff(),
        'gui':ChangeAromaticCutOffGUI},
    {'name':'AD3tors_writeFormattedPDBQ','cmd':AUTOTORSWriter(),
        'gui':AUTOTORSWriterGUI},
    ]


def initModule(vf):

    for dict in commandList:
        vf.addCommand(dict['cmd'],dict['name'],dict['gui'])
    
    if not hasattr(vf, 'ADTSetMode'):
        vf.addCommand(AdtSetMode(), 'ADTSetMode')
    if not hasattr(vf, 'ADtors_limitTorsions'):
        vf.addCommand(SetTorsionNumber(), 'ADtors_limitTorsions')
    if not hasattr(vf, 'ADtors_setBondRotatableFlag'):
        vf.addCommand(SetBondRotatableFlag(), 'ADtors_setBondRotatableFlag')
    if not hasattr(vf, 'ADtors_stop'):
        vf.addCommand(StopAutoTors(), 'ADtors_stop')

    if vf.hasGui:
        vf.GUI.menuBars['AutoTools3Bar']._frame.config( {'background':'tan'})
        for item in vf.GUI.menuBars['AutoTools3Bar'].menubuttons.values():
            item.configure(background = 'tan')
        if not hasattr(vf.GUI, 'adt3Bar'):
            vf.GUI.adt3Bar = vf.GUI.menuBars['AutoTools3Bar']
            vf.GUI.adt3Frame = vf.GUI.adt3Bar.menubuttons.values()[0].master
        if not hasattr(vf.GUI, 'adt3ModeLabel'):
            mbs = {}
            packing_list = []
            for c in vf.GUI.adt3Frame.children.values():
                if isinstance(c, Tkinter.Menubutton):
                    mbs[c.cget('text')] = c
                    packing_list.append(c.cget('text'))
                    c.pack_forget()
            vf.GUI.adt3ModeLabel=Tkinter.Label(vf.GUI.adt3Frame, text="ADT3.0", width=6,
                             relief='sunken', borderwidth=1, fg='DarkBlue',
                             bg = 'ivory',anchor='w' )
            vf.GUI.adt3ModeLabel.pack(side='left')
            vf.GUI.adt3ModeLabel.bind("<Double-Button-1>", vf.ADTSetMode.guiCallback())
            for t in packing_list:
                try:
                    c = mbs[t]
                    c.pack(side='left')
                except:
                    pass

#        if not hasattr(vf.GUI, 'ligandLabel'):
#            vf.GUI.ligandLabelLabel = Tkinter.Label(vf.GUI.adtFrame, \
#                            text="Ligand:", bg='tan')
#            vf.GUI.ligandLabelLabel.pack(side='left')
#            vf.GUI.ligandLabel=Tkinter.Label(vf.GUI.adtFrame, text="None", width=4,
#                                     relief='sunken', borderwidth=1,
#                                     anchor='w' )
#            vf.GUI.ligandLabel.pack(side='left')





#############################################################################
#
# Author: Ruth HUEY, Stefano FORLI
#
# Copyright: A. Olson TSRI 2010
#
#############################################################################


# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/DockingFilters.py,v 1.2 2010/04/30 19:53:41 rhuey Exp $
#
# $Id: DockingFilters.py,v 1.2 2010/04/30 19:53:41 rhuey Exp $
#
#
#
#
#
#
#

"""
Assorted classes of filters for use in selecting subgroups of AutoDock Virtual Screening results...

filter_instance.filter(docking) returns True/False 

"""

class Filter:
    """
        Base class for object to screen docking results
        input for filter: a docking instance of the AutoDockTools 'Docking' class
        output: whether the docking pass the criteria
    """
    def __init__(self, criteria='base_class'):
        self.criteria = criteria


    def filter(self, docking):
        return True



class EnergyFilter(Filter):
    """
        object to evaluate a docking results
        based on lowest energy of best docked result
        input: an AutoDockTools.Docking 'docking' 
        output: whether the best energy of docking is smaller than energy 
    """
    
    def __init__(self, energy=0):
        self.criteria = "BE"  
        Filter.__init__(self, self.criteria)
        self.energy = energy


        
    def filter(self, docking, rms=2.0):
        d = docking
        cl = d.clusterer
        clg = cl.clustering_dict[rms]
        val = cl.data[cl.argsort[0]].energy
        return val<self.energy



class ClusterSizeFilter(Filter):
    """
        object to evaluate a docking results
        based on size of the largest cluster  
        input: an AutoDockTools.Docking 'docking' 
        output: whether the largest cluster in the docking is at least as
        large as specified cluster_size
    """
    
    def __init__(self, cluster_size=0): 
        self.criteria = "LCsize"
        Filter.__init__(self, self.criteria)
        self.cluster_size = cluster_size


    def filter(self, docking, rms=2.0):
        d = docking
        clg = d.clusterer.clustering_dict[rms]
        largest_cl = 0
        for cl in clg: 
            #find largest cluster in this docking
            if len(cl)>largest_cl:
                largest_cl = len(cl)
        return largest_cl > self.cluster_size



class ClusterPercentageFilter(Filter):
    """
        object to evaluate a docking results
        based on percentage of dockings in the largest cluster  
        input: an AutoDockTools.Docking 'docking' 
        output: whether the largest cluster in the docking contains 
        at least the specified percentage of dockings
    """
    
    def __init__(self, percentage=0): 
        self.criteria = "LCpercentage"
        Filter.__init__(self, self.criteria)
        self.cluster_percentage = percentage


    def filter(self, docking, rms=2.0):
        d = docking
        clg = d.clusterer.clustering_dict[rms]
        largest_cl = 0
        num_conf = len(d.clusterer.data)
        for cl in clg: 
            #find largest cluster in this docking
            if len(cl)>largest_cl:
                largest_cl = len(cl)
        percent = 100.*(largest_cl/(1.0*num_conf))
        return percent > self.cluster_percentage


        
class EnergyClusterSizeFilter(Filter):
    """
        object to evaluate a docking results based on: 
        an energy and a size for the largest cluster
        input: an AutoDockTools.Docking 'docking' 
        output: whether the lowest energy is at least as small as specified
        value AND whether largest cluster in the docking is at least as
        large as specified cluster_size
    """

    def __init__(self, energy=0, cluster_size=0):
        self.criteria = "BE_Csize"  
        Filter.__init__(self, self.criteria)
        self.energyF = EnergyFilter(energy=energy)
        self.cluster_sizeF = ClusterSizeFilter(cluster_size=cluster_size)
        self.cluster_size = cluster_size


    def filter(self, docking, rms=2.0):
        d = docking
        cl = d.clusterer
        clg = cl.clustering_dict[rms]
        conf = cl.data[cl.argsort[0]]
        e_val = conf.energy
        if not self.energyF.filter(docking,rms):
            return False
        # so it passed the energy
        if not self.cluster_sizeF.filter(docking,rms):
            return False
        # so it passed both the energy and cluster_size
        return True



class EnergyLargestClusterFilter(Filter):
    """
        class for object to screen docking results
        based on the magnitude of best energy and whether that conf is in the largest cluster 
        input: an AutoDock docking 
        output: whether the docking passes these criteria
    """

    def __init__(self, energy=0):
        self.criteria = "BE_LC"  
        Filter.__init__(self, self.criteria)
        self.energyF = EnergyFilter(energy=energy)


    def filter(self, docking, rms=2.0):
        d = docking
        cl = d.clusterer
        clg = cl.clustering_dict[rms]
        conf = cl.data[cl.argsort[0]]
        e_val = conf.energy
        if not self.energyF.filter(docking,rms):
            return False
        #find the largest cluster
        cl_lengths = []
        for cl in clg: cl_lengths.append(len(cl))
        LC_ind = cl_lengths.index(max(cl_lengths))
        largest_cluster = clg[LC_ind]
        #SO is conf in this cluster  or not?
        return conf in largest_cluster



class LigandEfficiencyFilter(Filter):
    """
        class for object to screen docking results
        based on the ligand efficiency measure
        which is the best energy divided by the number 
        of heavy atoms in the ligand
        input: an AutoDock docking 
        output: whether the docking passes the criteria
    """

    def __init__(self, ligand_efficiency=0):
        self.criteria = "Ligand_efficiency"  
        Filter.__init__(self, self.criteria)
        self.ligand_efficiency = ligand_efficiency


    def filter(self, docking):
        d = docking
        cl = d.clusterer
        rms = cl.clustering_dict.keys()[0]
        clg = cl.clustering_dict[rms]
        conf = cl.data[cl.argsort[0]]
        return conf.ligand_efficiency<=self.ligand_efficiency



class InteractionFilter(Filter):       
    """
        @@YET TO BE DONE@@
        class for object to screen docking results
        based on specific interaction ligand-receptor 
        input: an AutoDock docking 
        output: whether the docking passes the criteria
    """

    def __init__(self, interactions=[]):
        self.criteria = "Ligand_efficiency"  
        Filter.__init__(self, self.criteria)
        self.interactions = interactions


    def filter(self, docking):
        d = docking
        cl = d.clusterer
        rms = cl.clustering_dict.keys()[0]
        clg = cl.clustering_dict[rms]
        conf = cl.data[cl.argsort[0]]
        all_passed = False
        # check for presence of all specified interactions
        return all_passed




#
#
#
#
# $Id: test_pdbqs_to_pdbqt.py,v 1.3 2011/09/07 23:00:37 annao Exp $
#

import unittest, os, sys
from string import split, find
from MolKit import Read

class BaseTests(unittest.TestCase):

    def test_default_formatted_pdbq(self):
        """
    pdbqs_to_pdbqt.py -s pdbqs_stem -o outputfilename
       -s ligand_stem
       optional:
       [-o outputfilename]

        """
        filename = "test_hsg1.pdbqt"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + '; ' + "../pdbqs_to_pdbqt.py -s hsg1 -o "+ filename
        #cmd = "../pdbqs_to_pdbqt.py -s 1ebg_lig -o "+ filename
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        fptr = open('ref_hsg1.pdbqt')
        reflines = fptr.readlines()
        fptr.close()
        fptr = open(filename)
        testlines = fptr.readlines()
        fptr = open(filename)
        for refline, testline in zip(reflines, testlines):
            # on linux, 0.000 is written -0.000 for atom 1844
            # whereas on sgi, it is written 0.000
            # this is a hack to skip that one character
            #self.assertEqual(refline[:-10], testline[:-10])
            #self.assertEqual(refline[-9:], testline[-9:])
            line1 = refline.strip().split()
            line2 = testline.strip().split()
            for s1, s2 in zip(line1, line2):
                if not s1.isalnum(): self.assertAlmostEqual(float(s1), float(s2), places=2)
                else: self.assertEqual(s1, s2)




if __name__ == '__main__':
    unittest.main()



########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Thursday 01 June 2006 15:52:40 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/AD3Dpf.py,v 1.1 2006/06/05 22:45:41 rhuey Exp $
#
# $Id: AD3Dpf.py,v 1.1 2006/06/05 22:45:41 rhuey Exp $
#

from NetworkEditor.macros import MacroNode
class AD3Dpf(MacroNode):

    def __init__(self, constrkw={}, name='AD3Dpf', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        net.editor.addLibraryInstance(adtlib,"AutoDockTools.VisionInterface.AdtNodes", "adtlib")

        from MolKit.VisionInterface.MolKitNodes import molkitlib
        net.editor.addLibraryInstance(molkitlib,"MolKit.VisionInterface.MolKitNodes", "molkitlib")

        from Vision.StandardNodes import stdlib
        net.editor.addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")


    def afterAddingToNetwork(self):
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        from MolKit.VisionInterface.MolKitNodes import molkitlib
        from Vision.StandardNodes import stdlib
        ## building macro network ##
        AD3Dpf_6 = self
        from traceback import print_exc

        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        self.macroNetwork.getEditor().addLibraryInstance(adtlib,"AutoDockTools.VisionInterface.AdtNodes", "adtlib")

        from MolKit.VisionInterface.MolKitNodes import molkitlib
        self.macroNetwork.getEditor().addLibraryInstance(molkitlib,"MolKit.VisionInterface.MolKitNodes", "molkitlib")

        from Vision.StandardNodes import stdlib
        self.macroNetwork.getEditor().addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")

        try:
            ## saving node input Ports ##
            input_Ports_7 = self.macroNetwork.ipNode
            input_Ports_7.move(158, 4)
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_7=None

        try:
            ## saving node output Ports ##
            output_Ports_8 = self.macroNetwork.opNode
            output_Ports_8.move(172, 322)
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_8=None

        try:
            ## saving node Docking Parameter File Browser ##
            from AutoDockTools.VisionInterface.AdtNodes import DockingParameterFileBrowserNE
            Docking_Parameter_File_Browser_9 = DockingParameterFileBrowserNE(constrkw = {}, name='Docking Parameter File Browser', library=adtlib)
            self.macroNetwork.addNode(Docking_Parameter_File_Browser_9,204,93)
            apply(Docking_Parameter_File_Browser_9.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Docking_Parameter_File_Browser_9.outputPortByName['filename'].configure, (), {'color': 'white', 'shape': 'oval'})
            Docking_Parameter_File_Browser_9.inputPortByName['filename'].widget.set("/mgl/work4/rhuey/dev23/NEWTEST.dpf", run=False)
        except:
            print "WARNING: failed to restore DockingParameterFileBrowserNE named Docking Parameter File Browser in network self.macroNetwork"
            print_exc()
            Docking_Parameter_File_Browser_9=None

        try:
            ## saving node Prepare AD3Dpf ##
            from AutoDockTools.VisionInterface.AdtNodes import AdtPrepareDpf3
            Prepare_AD3Dpf_10 = AdtPrepareDpf3(constrkw = {}, name='Prepare AD3Dpf', library=adtlib)
            self.macroNetwork.addNode(Prepare_AD3Dpf_10,170,266)
            apply(Prepare_AD3Dpf_10.inputPortByName['ligand_filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Dpf_10.inputPortByName['receptor_filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Dpf_10.inputPortByName['dpf_filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Dpf_10.inputPortByName['parameters'].configure, (), {'color': 'cyan', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Dpf_10.inputPortByName['outputfilename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Dpf_10.outputPortByName['ad3_parameter_file'].configure, (), {'color': 'white', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore AdtPrepareDpf3 named Prepare AD3Dpf in network self.macroNetwork"
            print_exc()
            Prepare_AD3Dpf_10=None

        try:
            ## saving node Read Molecule ##
            from MolKit.VisionInterface.MolKitNodes import ReadMolecule
            Read_Molecule_11 = ReadMolecule(constrkw = {}, name='Read Molecule', library=molkitlib)
            self.macroNetwork.addNode(Read_Molecule_11,94,51)
            apply(Read_Molecule_11.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Read_Molecule_11.outputPortByName['MolSets'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore ReadMolecule named Read Molecule in network self.macroNetwork"
            print_exc()
            Read_Molecule_11=None

        try:
            ## saving node Read Molecule ##
            from MolKit.VisionInterface.MolKitNodes import ReadMolecule
            Read_Molecule_12 = ReadMolecule(constrkw = {}, name='Read Molecule', library=molkitlib)
            self.macroNetwork.addNode(Read_Molecule_12,187,47)
            apply(Read_Molecule_12.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Read_Molecule_12.outputPortByName['MolSets'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore ReadMolecule named Read Molecule in network self.macroNetwork"
            print_exc()
            Read_Molecule_12=None

        try:
            ## saving node File Browser ##
            from Vision.StandardNodes import FileBrowserNE
            File_Browser_13 = FileBrowserNE(constrkw = {}, name='File Browser', library=stdlib)
            self.macroNetwork.addNode(File_Browser_13,286,143)
            apply(File_Browser_13.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(File_Browser_13.outputPortByName['filename'].configure, (), {'color': 'white', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore FileBrowserNE named File Browser in network self.macroNetwork"
            print_exc()
            File_Browser_13=None

        self.macroNetwork.freeze()

        ## saving connections for network AD3Dpf ##
        if Docking_Parameter_File_Browser_9 is not None and Prepare_AD3Dpf_10 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Docking_Parameter_File_Browser_9, Prepare_AD3Dpf_10, "filename", "dpf_filename", blocking=True)
            except:
                print "WARNING: failed to restore connection between Docking_Parameter_File_Browser_9 and Prepare_AD3Dpf_10 in network self.macroNetwork"
        if Read_Molecule_11 is not None and Prepare_AD3Dpf_10 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Read_Molecule_11, Prepare_AD3Dpf_10, "MolSets", "ligand_filename", blocking=True)
            except:
                print "WARNING: failed to restore connection between Read_Molecule_11 and Prepare_AD3Dpf_10 in network self.macroNetwork"
        if Read_Molecule_12 is not None and Prepare_AD3Dpf_10 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Read_Molecule_12, Prepare_AD3Dpf_10, "MolSets", "receptor_filename", blocking=True)
            except:
                print "WARNING: failed to restore connection between Read_Molecule_12 and Prepare_AD3Dpf_10 in network self.macroNetwork"
        if File_Browser_13 is not None and Prepare_AD3Dpf_10 is not None:
            try:
                self.macroNetwork.connectNodes(
                    File_Browser_13, Prepare_AD3Dpf_10, "filename", "outputfilename", blocking=True)
            except:
                print "WARNING: failed to restore connection between File_Browser_13 and Prepare_AD3Dpf_10 in network self.macroNetwork"
        output_Ports_8 = self.macroNetwork.opNode
        if Prepare_AD3Dpf_10 is not None and output_Ports_8 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Prepare_AD3Dpf_10, output_Ports_8, "ad3_parameter_file", "new", blocking=True)
            except:
                print "WARNING: failed to restore connection between Prepare_AD3Dpf_10 and output_Ports_8 in network self.macroNetwork"
        self.macroNetwork.unfreeze()

        AD3Dpf_6.shrink()

        ## reset modifications ##
        AD3Dpf_6.resetTags()
        AD3Dpf_6.buildOriginalList()



#!/usr/bin/env python
#$Id: write_random_state_ligand.py,v 1.3 2008/03/04 17:58:57 rhuey Exp $
import os
import random
from MolKit import Read
from MolKit.molecule import BondSet
from mglutil.math.statetocoords import StateToCoords
from AutoDockTools.Conformation import Conformation
#from MolKit.pdbWriter import PdbqWriter, PdbqtWriter




if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: write_random_state_ligand.py -l filename"
        print "    Description of command..."
        print "        [-l]    ligand filename"
        print "    Optional parameters:"
        print "        [-o]    alternative output filename"
        print "        (default is filename_stem+'_random_.pdbqt')"
        print "        [-t]    translation scale"
        print "                 (default is 10)"
        print "        [-x]    axis scale"
        print "                 (default is 2)"
        print "        [-a]    angle scale"
        print "                 (default is 360)"
        print "        [-d]    torsion scale"
        print "                 (default is 90)"
        print "        [-n]    number of tries"
        print "                 (default is 20)"
        print "        [-v]    verbose output"
        print

    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'l:o:t:x:a:d:n:vh')

    except getopt.GetoptError, msg:
        print 'write_random_state_ligand.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-l: pdbq(t)_filename
    filename =  None
    tscale = 10.  #translation scale
    xscale = 2.   #axis scale
    ascale = 360.   #angle scale
    dscale = 90.  #torsion scale
    ntries = 20

    # optional parameters
    verbose = None
    outputfilename =  None

    #'l:o:t:x:a:d:n:vh'
    for o, a in opt_list:
        if o in ('-l', '--l'):
            filename = a
            if verbose: print 'set filename to ', filename
            stem, ext = os.path.splitext(filename)
            stem =stem.split('_')[0]
            outputfilename =  stem + '_random' + ext
            if verbose: print " default outputfilename is ", outputfilename
        if o in ('-t', '--t'):
            tscale = float(a)
            if verbose: print 'set translation scale factor to ', tscale
        if o in ('-x', '--x'):
            xscale = a
            if verbose: print 'set axis scale factor  to ', xscale
        if o in ('-a', '--a'):
            ascale = float(a)
            if verbose: print 'set angle scale factor to ', ascale
        if o in ('-d', '--d'):
            dscale = float(a)
            if verbose: print 'set torsions scale factor to ', dscale
        if o in ('-n', '--n'):
            ntries = int(a)
            if verbose: print 'set number of tries to ', ntries
        if o in ('-o', '--o'):
            outputfilename = a 
            if verbose: print 'set output outputfilename to ', a
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()

    if not filename:
        print 'write_random_state_ligand: filename must be specified.'
        usage()
        sys.exit()

    m = Read(filename)[0]
    if verbose: print 'read ', filename
    #validate specified ligand file
    assert hasattr(m, 'torTree'), "specified ligand does not have a torsion tree"
    ndihe = m.parser.keys.count('BRANCH')
    if verbose: print m.name, ' has ', ndihe, ' torsions'

    #1. prepare molecule 
    m.buildBondsByDistance()
    orig_coords = m.allAtoms.coords[:]
    m.allAtoms.addConformation(m.allAtoms.coords)
    coord_index = 1
    origin = m.getCenter()
    m.stoc = StateToCoords(m, origin, 1)
    #build reference dictionary of original bonds
    orig = len(m.allAtoms.bonds[0])
    orig_d = {}
    for a in m.allAtoms: orig_d[a]=set(a.bonds.getAtoms())

    #try a new random state up to ntries times
    # convert trans to space centered on m
    for new_try in range(ntries):
        #reset coords in working slot to original coords for new try
        m.allAtoms.updateCoords(orig_coords, ind=coord_index)
        TRANS = []
        for ind in range(3):
            #do not subtract origin here, i don't understand why not
            #TRANS.append((random.uniform(-1,1)*tscale)-origin[i])
            TRANS.append(random.uniform(-1,1)*tscale)
        if verbose: print 'translation=', TRANS
        #rot = [1,0,0,180]
        #for the rotation axis, use xscale
        rot = []
        for ind in range(3):
            rot.append(random.uniform(-1,1)*xscale)
        #for the rotation angle
        rot.append(random.uniform(-1,1)*ascale)
        if verbose: print 'axis=', rot[:3], ' and angle=', rot[-1]
        #torsions:
        dihe = []
        for ind in range(ndihe):
            dihe.append(dscale * random.uniform(-1,1))
        if verbose: print 'dihe=', dihe
        conf = Conformation(m, origin, TRANS, rot, dihe)
        new_coords = conf.getCoords()
        #verify that no new bonds would be formed for this conformation
        m.allAtoms.updateCoords(new_coords, ind=coord_index)
        #remove all original bonds and set hasBonds to 0 on all levels
        del(m.allAtoms.bonds)
        m.hasBonds=0
        for c in m.chains: c.hasBonds=0
        for r in m.chains.residues: r.hasBonds=0
        for a in m.allAtoms: 
            a.bonds = BondSet([])
            a.hasBonds = 0
        m.buildBondsByDistance()
        newLen = len(m.allAtoms.bonds[0])
        if verbose: print "originally %d bonds form; after transformation %d bonds form" %(orig, newLen)
        new_d = {}
        for a in m.allAtoms: new_d[a]=set(a.bonds.getAtoms())
        ok = True
        for a in m.allAtoms:
            if orig_d[a]!=new_d[a]:
                ok = False
                if verbose: 
                    print "bonds differ for %s: %d v %d" %(a.full_name(), len(orig_d[a]), len(new_d[a]))
        #for a in m.allAtoms:
        #    assert orig_d[a]==new_d[a], '%s bonds differ: %d v %d' %(a.full_name(), len(orig_d[a]), len(new_d[a]))
        if verbose: print "end of try ", new_try+1
        if ok: 
            print "new conformation found in",
            if new_try==0:
                print "1 try" 
            else:
                print "%d tries" %(new_try+1)
            break
    if ok:
        if verbose: 
            print 'no new contacts formed so writing file after ', new_try+1,
            if new_try==0:
                print ' try...'
            else:
                print ' tries...'
        m.parser.write_with_new_coords(new_coords, outputfilename)
        if verbose: print "wrote new conformation in ", outputfilename
    else:
        print "FAILED! no new conformation found in %d attempts!!!" %ntries


# To execute this command type:
# write_random_state_ligand.py -l ligand filename -t translation -a axisangle -d torsions [-o outputfilename] -v verbose output



#
#
#
#
# $Id: test_AutoDockBondClassifier.py,v 1.1 2004/06/08 18:56:41 rhuey Exp $
#

import unittest, os
from string import split
from AutoDockTools.AutoDockBondClassifier import AutoDockBondClassifier
from MolKit import molecule, protein
molecule.bhtreeFlag = 0
protein.bhtreeFlag = 0


class BaseTests(unittest.TestCase):
    def setUp(self):
        from MolKit import Read
        self.mol = Read('ind.out.pdbq')[0]
        self.mol.buildBondsByDistance()
    

    def tearDown(self):
        """
        clean-up
        """
        del(self.mol)


    def test_constructor(self):
        """
        instantiate an AutoDockBondClassifier
        """
        adbc = AutoDockBondClassifier()
        self.assertEquals(adbc.__class__, AutoDockBondClassifier)



    def test_classify(self):
        """
         test that AutoDockBondClassifier can classify bonds
        """
        adbc = AutoDockBondClassifier()
        resultDict = adbc.classify(self.mol.allAtoms.bonds[0])
        for k in ['amide', 'ppbb','leaf','cycle','rotatable',
                    'hydrogenRotators', 'guanidinium']:
            self.assertEquals(resultDict.has_key(k), True)


    def test_classify_results(self):
        """
         test results set by adbc
        """
        adbc = AutoDockBondClassifier()
        resultDict = adbc.classify(self.mol.allAtoms.bonds[0])
        results = {}
        results['amide'] = 2
        results['ppbb'] = 0
        results['leaf'] = 9
        results['cycle'] = 28
        results['rotatable'] = 16
        results['hydrogenRotators'] = 2
        results['guanidinium'] = 0
        for k, v in results.items():
            #print k, ':', v,' vs ', len(resultDict[k])
            self.assertEquals(len(resultDict[k]), v)



if __name__ == '__main__':
    unittest.main()



#########################################################################
#
# Date: Nov 2001 Authors: Michel Sanner
#
#    sanner@scripps.edu
#
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Michel Sanner and TSRI
#
#########################################################################

from NetworkEditor.items import NetworkNode

from AutoDockTools.filterLigands import FilterLigands
from AutoDockTools.VisionInterface.Adt.LigandDB import LigandDB

class FilterLigandsNode(NetworkNode):
    """
    A node that takes a ligandDB, applies filtering and output a LigandList
    """

    attr = [
        'HbAMin', 'HbAMax', 'HbDMin', 'HbDMax', 'MWMin', 'MWMax',
        'NatMin', 'NatMax', 'TORSDOFMin', 'TORSDOFMax' ]

    def setParamPanelWidget(self, lfilter):
        """
        Set the widgets of the parameter panel to the filtering values without
        triggering network execution
        """
        for i in range(10):
            w = self.inputPorts[2+i].widget
            value = getattr(lfilter, self.attr[i])
            if value in [None, 'None']:
                w.configure(showLabel=0)
            else:
                w.configure(showLabel=1)
                w.set(value, run=0)


    def __init__(self, name='filterLigands', **kw):
        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )

        # create filter object
        lfilter = self.lfilter = FilterLigands()
        lfilter.setFilter('default')
        
        ip = self.inputPortsDescr
        ip.append(datatype='LigandDB', name='ligands')
        ip.append(datatype='string', name='filterMode')

        self.widgetDescr['filterMode'] = {
            'class':'NEComboBox', 'master':'node',
            'choices':['None', 'default', 'Lipinski-like', 'Drug-like', 'Drug-like frag', 'Custom'],
            'fixedChoices':True,
            'initialValue':'default',
            'entryfield_entry_width':8,
            'labelGridCfg':{'sticky':'w'},
            'widgetGridCfg':{'sticky':'w'},
            'labelCfg':{'text':'filter type:'}}

        labels = [
            'Min num. of h-bond donors:',
            'Max num. of h-bond donors:',
            'Min num. of h-bond acceptors',
            'Max num. of h-bond acceptors',
            'Min molecular weight',
            'Max molecular weight',
            'Min num. of heavy atoms',
            'Max num. of heavy atoms',
            'Min num. of rotatable bonds',
            'Max num. of rotatable bonds'
            ]

        for i, param in enumerate( ['hbd_min', 'hbd_max', 'hba_min', 'hba_max',
                                    'mw_min', 'mw_max', 'nat_min', 'nat_max',
                                    'torsdof_min', 'torsdof_max'] ):
            ip.append(datatype='int', name=param)
            value = getattr(lfilter, self.attr[i])
            
            self.widgetDescr[param] = {
                'class':'NEThumbWheel','master':'ParamPanel', 
                'width':75, 'height':12, 'oneTurn':10, 'type':'int',
                'wheelPad':0, 'initialValue':value, 'min':0,
                'labelCfg':{'text':labels[i]} }

        op = self.outputPortsDescr
        op.append(datatype='LigandDB', name='ligands')
        op.append(datatype='int', name='num_accepted')
        op.append(datatype='int', name='num_rejected')

        code = """def doit(self, ligands, filterMode='default', hbd_min=None, hbd_max=None, hba_min=None, hba_max=None, mw_min=None, mw_max=None, nat_min=None, nat_max=None, torsdof_min=None, torsdof_max=None):

    lfilter = self.lfilter

    if filterMode != "Custom":
        lfilter.setFilter(filterMode)
    else:
        kwargs = {"HbDMin": hbd_min,
                  "HbDMax": hbd_max,
                  "HbAMin": hba_min,
                  "HbAMax": hba_max,
                  "MWMin": mw_min,
                  "MWMax": mw_max,
                  "NatMin": nat_min,
                  "NatMax": nat_max,
                  "TORSDOFMin": torsdof_min,
                  "TORSDOFMax": torsdof_max}
        lfilter.setFilterRanges('Custom', **kwargs)

    if self.inputPorts[1].hasNewValidData(): # new mode -> update widgets
        self.setParamPanelWidget(lfilter)

    print "Running Filter node with parameters:"
    print "min number of hydrogen bond donors: " + str(lfilter.HbDMin)
    print "max number of hydrogen bond donors: " + str(lfilter.HbDMax)
    print "min number of hydrogen bond acceptors: " + str(lfilter.HbAMin)
    print "max number of hydrogen bond acceptors: " + str(lfilter.HbAMax)
    print "min molecular weight: " + str(lfilter.MWMin)
    print "max molecular weight: " + str(lfilter.MWMax)
    print "min number of heavy atoms: " + str(lfilter.NatMin)
    print "max number of heavy atoms: " + str(lfilter.NatMax)
    print "min number of rotatable bonds: " + str(lfilter.TORSDOFMin)
    print "max number of rotatable bonds: " + str(lfilter.TORSDOFMax)

#    accepted, rejected = lfilter.filterTable(ligands.propertyTable)

    accepted, rejected = lfilter.filterTable(ligands.propertyTable, ligands.accepted)

    ligands.SetAcceptedLigands(accepted.filenames)

    if len(accepted.filenames) > 2500:
        print "ERROR: Sorry, we cannot send your virtual screening job to the server because the number of accepted ligands from the filter is greater than the maximum number of ligands (2500) the server can support"
        return 'stop'

    self.outputData(ligands=ligands, num_accepted = len(accepted.filenames), num_rejected=len(rejected))
"""
        self.setFunction(code)



#!/usr/bin/env python

import os
from string import find

from MolKit import Read
from MolKit.pdbWriter import PdbqsWriter
from AutoDockTools.atomTypeTools import SolvationParameterizer




if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: pdbqt_to_pdbqs.py -s filename"
        print
        print "    Description of command..."
        print "        [-s]    receptor_filename_stem"
        print "    Optional parameters:"
        print "        [-o]    alternative pdbqs_filename"
        print "        [-v]    verbose output"


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 's:o:v')

    except getopt.GetoptError, msg:
        print 'pdbqt_to_pdbqs.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-s: pdbqt_filename_stem
    pdbqt_filename =  None

    # optional parameters
    verbose = None
    pdbqs_filename =  None

    #'s:o:v'
    for o, a in opt_list:
        if o in ('-s', '--s'):
            pdbqt_filename = a + ".pdbqt"
            pdbqs_filename = a + ".pdbqs"
            if verbose: print 'set AD4 receptor_filename to ', pdbqt_filename
        if o in ('-o', '--o'):
            pdbqs_filename = a 
            if verbose: 
                print 'set AD3 pdbqs_filename to ', a
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()


    if not pdbqt_filename:
        print 'pdbqt_to_pdbqs: pdbqt_filename_stem must be specified.'
        usage()
        sys.exit()

    #what about nucleic acids???

    mols = Read(pdbqt_filename)
    if verbose: print 'read ', pdbqt_filename
    mol = mols[0]
    #fix number for problem files with alternative positions
    mol.allAtoms.number = range(1, len(mol.allAtoms)+1)

    #possible clean-up???
    #need to type atoms + assign babel_types
    solparer = SolvationParameterizer()
    solparer.addParameters(mol.allAtoms)
    if verbose:
        print "set autodock3 solvation parameters for ", mol.name

    #pdbqs_filename = mol.name + '.pdbqs'
    writer = PdbqsWriter()
    fptr = open(pdbqs_filename, 'w')
    ctr = 0
    for line in mol.parser.allLines:
        if find(line, 'ATOM')<0 and find(line, "HETA")<0:
            fptr.write(line)
        else:
            this_atom = mol.allAtoms[ctr]
            writer.write_atom(fptr, this_atom)
            ctr = ctr + 1
    fptr.close()
    if verbose:
        print "wrote ", ctr, " atoms to", pdbqs_filename
    

# To execute this command type:
# pdbqt_to_pdbqs.py -s pdbqt_filename_stem  -v







#!/usr/bin/env python

from distutils.core import setup
from distutils.command.sdist import sdist
from distutils.command.install_data import install_data
from distutils.command.build_scripts import build_scripts
from glob import glob
import os

########################################################################
# Had to overwrite the prunrefile_list method of sdist to not
# remove automatically the RCS/CVS directory from the distribution.
########################################################################

class modified_sdist(sdist):
    def prune_file_list(self):
        """
        Prune off branches that might slip into the file list as created
        by 'read_template()', but really don't belong there:
          * the build tree (typically 'build')
          * the release tree itself (only an issue if we ran 'sdist
            previously with --keep-temp, or it aborted)
        """
        build = self.get_finalized_command('build')
        base_dir = self.distribution.get_fullname()
        self.filelist.exclude_pattern(None, prefix=build.build_base)
        self.filelist.exclude_pattern(None, prefix=base_dir)

class modified_install_data(install_data):

    def run(self):
        install_cmd = self.get_finalized_command('install')
        self.install_dir = getattr(install_cmd, 'install_lib')
        return install_data.run(self)

class modified_build_scripts(build_scripts):
    
    def copy_scripts(self):
        #print "scripts:" , self.scripts
        ## copy runAdt.py to runAdt, inserting "#!python" line at the beginning 
        for script in self.scripts:
            fnew = open(script, "w")
            forig = open(script+".py", "r")
            txt = forig.readlines()
            forig.close()
            fnew.write("#!/usr/bin/env python2.4\n")
            fnew.writelines(txt)
            fnew.close()
        build_scripts.copy_scripts(self)


########################################################################

# list of the python packages to be included in this distribution.
# sdist doesn't go recursively into subpackages so they need to be
# explicitaly listed.
# From these packages only the python modules will be taken
packages = ['AutoDockTools', 
            'AutoDockTools.Tests', 
            'AutoDockTools.Objects',
            #'AutoDockTools.Utilities',
            #'AutoDockTools.Utilities.Tests',
            'AutoDockTools.Utilities24',
            'AutoDockTools.Utilities24.Tests',
            'AutoDockTools.VisionInterface',
            'AutoDockTools.VisionInterface.Adt',
            'AutoDockTools.VisionInterface.Adt.Input',
            'AutoDockTools.VisionInterface.Adt.Macro',
            'AutoDockTools.VisionInterface.Adt.Mapper',
            'AutoDockTools.VisionInterface.Adt.Other',
            'AutoDockTools.VisionInterface.Adt.Output',
            'AutoDockTools.VisionInterface.Adt.Filter',
            'AutoDockTools.CADD',
            'AutoDockTools.CADD.VisionNetworks',
            ]

# list of the python modules not part of a package. Give the path and the
# filename without the extension. i.e you want to add the
# test.py module which is located in MyPack/Tests/ you give
# 'MyPack/Tests/test'
py_modules = ['AutoDockTools/bin/runAdt']

# list of the files that are not python packages but are included in the
# distribution and need to be installed at the proper place  by distutils.
# The list in MANIFEST.in lists is needed for including those files in
# the distribution, data_files in setup.py is needed to install them
# at the right place.
from string import split
data_files = []
def getDataFiles(file_list, directory, names):
    dir_list = split(directory, os.sep)
    if len(dir_list) > 1:
        ff = dir_list[1]
        if ff  == 'Utilities' or ff == 'doc':
            #print "do not include Utilities and doc files"
            return
    
    fs = []
    for name in names:
        ext = os.path.splitext(name)[1]
        #print directory, name, ext, len(ext)
        if ext !=".py" and ext !=".pyc":
            fullname = os.path.join(directory,name)
            if not os.path.isdir(fullname):
                fs.append(fullname)
    if len(fs):
        file_list.append((directory, fs))

os.path.walk("AutoDockTools", getDataFiles, data_files)
#print "data_files:", data_files, len(data_files)


# description of what is going to be included in the distribution and
# installed.
from version import VERSION
setup (name = 'AutoDockTools',
       version = VERSION,
       description = "ADT is a GUI to help set up, launch and analyze AutoDock  dockings",
       author = 'Molecular Graphics Laboratory',
       author_email = 'rhuey@scripps.edu',
       download_url = 'http://www.scripps.edu/~sanner/software/packager.html',
       url = 'http://www.scripps.edu/~sanner/python/adt/autotoolsoverview.html',
       packages = packages,
       py_modules = py_modules,
       data_files = data_files,
       scripts = ['AutoDockTools/bin/runAdt'],
       cmdclass = {'sdist': modified_sdist,
                   'install_data': modified_install_data,
                   'build_scripts': modified_build_scripts
                   },
       )



## Automatically adapted for numpy.oldnumeric Jul 23, 2007 by 

#
#
# $Id: AutoDockBondClassifier.py,v 1.9 2008/08/13 19:08:24 rhuey Exp $
#
#
#
#


from MolKit.bondClassifier import BondClassifier
from MolKit.bondSelector import AmideBondSelector, PeptideBackBoneBondSelector
from MolKit.bondSelector import HydrogenRotatorBondSelector, RotatableBondSelector
from MolKit.bondSelector import LeafBondSelector, CycleBondSelector
from MolKit.bondSelector import GuanidiniumBondSelector, BondOrderBondSelector 
from MolKit.bondSelector import AromaticCycleBondSelector2
from MolKit.molecule import BondSet
       
def dist(c1, c2):       
    import numpy.oldnumeric as Numeric, math
    d = Numeric.array(c2) - Numeric.array(c1) 
    ans = math.sqrt(Numeric.sum(d*d))
    return round(ans, 3)


class AutoDockBondClassifier(BondClassifier):

    def __init__(self, tolerance=0.01, detectAll=True):
        self.detect_all_cycles = detectAll
        self.d = {
            'amide':AmideBondSelector(),
            'ppbb':PeptideBackBoneBondSelector(),
            'leaf':LeafBondSelector(),
            'cycle':CycleBondSelector(),
            'rotatable':RotatableBondSelector(),
            'bondOrder2':BondOrderBondSelector(2),
            'hydrogenRotators':HydrogenRotatorBondSelector(),
            'guanidinium':GuanidiniumBondSelector(),
            'aromatic': AromaticCycleBondSelector2()

            }
        BondClassifier.__init__(self, self.d)
        #used to detect colinear atoms
        #if dist1+dist2<dist13+0.1
        self.tolerance = 0.01
#NOTE hydrogenRotators value is a group of ATOMS not BONDS


    def classify(self, bonds=None):
        """ 
        select using each bondselector (the values of the dict); store result
        in resultDict and return the result dict when finished...
        """
        #make sure that classify is called with some bonds
        assert isinstance(bonds, BondSet)
        resultDict = {}
        rotatables = self.d['rotatable'].select(bonds)

        for k, v in self.dict.items():
            if k=='bondOrder2':
                resultDict[k] = v.select(bonds,2)
            elif k=='cycle':
                resultDict[k] = v.select(bonds,self.detect_all_cycles)
            else:
                resultDict[k] = v.select(bonds)
        bnds = resultDict['leaf']
        for b in bnds:
            at1 = b.atom1
            at2 = b.atom2
            if len(at1.bonds)==1:
                at1.leaf = 1
                if len(at2.bonds)==2:
                    dist1 = dist(at1.coords, at2.coords)
                    #find neighbor of at2 and check bond distances
                    b2 = at2.bonds[0]
                    if b2==b:
                        b2 = at2.bonds[1]
                    neighbor = b2.atom1
                    if neighbor==at2:
                        neighbor = b2.atom2
                    dist2 = dist(neighbor.coords, at2.coords)
                    dist13 = dist(at1.coords, neighbor.coords)
                    if dist13+self.tolerance>=dist1+dist2:
                        #print "adding ", b2, 'to leaf bonds'
                        resultDict['leaf'].append(b2)
                        if b2 in resultDict['rotatable']:
                            resultDict['rotatable'].remove(b2)
            elif len(at2.bonds)==1:
                at2.leaf = 1
                if len(at1.bonds)==2:
                    dist1 = dist(at1.coords, at2.coords)
                    #find neighbor of at1 and check bond distances
                    b2 = at1.bonds[0]
                    if b2==b:
                        b2 = at1.bonds[1]
                    neighbor = b2.atom1
                    if neighbor==at1:
                        neighbor = b2.atom2
                    dist2 = dist(neighbor.coords, at1.coords)
                    dist13 = dist(at2.coords, neighbor.coords)
                    if dist13+self.tolerance>=dist1+dist2:
                        resultDict['leaf'].append(b2)
                        #print "2: adding ", b2, 'to leaf bonds'
                        b2.possibleTors=0
                        if b2 in resultDict['rotatable']:
                            resultDict['rotatable'].remove(b2)
                    
        #8/16:NOTE only select from rotatables for amide+ guanidinium 
        for k in ['amide', 'guanidinium']:
            resultDict[k] = self.d[k].select(rotatables)
        return resultDict





#############################################################################
#
# Author: Ruth HUEY, Michel F. SANNER
#
# Copyright: M. Sanner TSRI 2000
#
#############################################################################


# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/autoanalyze41Commands.py,v 1.11 2010/07/08 22:19:50 rhuey Exp $
#
# $Id: autoanalyze41Commands.py,v 1.11 2010/07/08 22:19:50 rhuey Exp $
#
#
#
#
#
#
#

"""
This Module facilitates analyzing results of autodock jobs. 

    * The first step is 'Read Docking Log'  The selected file is parsed 
    which sets self.docked to a new Docking instance.  The Docking class 
    has attributes:

        o dlgParser

            x 'dlg': full pathname of dlg

        o dpo 

        o ch:a conformation handler.

            x 'clusterNum': 

            x 'clusterList': 

            x 'modelList': a list of docked conformations 

        o macroFile: the Macromolecule file used

        o 'macro': filename of macromolecule (eg '1hvrCorr.pdbqt')

        o 'macroStem': name of macromolecule up to last '.' (eg '1hvrCorr')

        o ligand:  the original ligand 

        o output: lines containing summary of docking

    The new Docking is also entered in the dictionary 'dockings' as a separate item 
    whose key is the file and whose value is the Docking.


After the selected docking log file is parsed, the user can:

    * select a displayed docked conformation using the 'Choose A Docked Conformation' menubutton.  This opens a DockingChooser widget which is a ListChooser allowing selection either in the widget or in the viewer of any of the displayed docking. Information about each docked conformation is displayed in the information window of the DockingChooser as different entries are high-lighted.  

    * display the macromolecule via the "Show Macromolecule" menubutton.  This menubutton is linked to a file browsers in case the macromolecule whose name is parsed from the docking log file is not in the current directory. (FIX THIS: what if the macromolecule is in a different directory but there is a molecule with the same name here???). The user can change the visibility, sampling, isovalue, renderMode and visibility of bounding box  for each of  the displayed grids

    * display the autogrids used in the docking via the "Show Grids Used For Calc" menubutton.  This menubutton is linked to a ListChooser which lets the user select whether to load all or some of the grids. The user can interactively change the visibility of each grid's isosurface, its sampling value, its isovalue, its rendermode (LINE or FILL) and the visibility of its bounding box. 

    * The user is able to visualize extra grid maps using the "Show Grid" button. 

    * If the current docking has clusters, the user is able to visualize a results histogram for it with 'Show Histogram'. The histogram can be printed.

    * Result Summaries for docking(s) can be viewed, edited and saved with 'Get Output'

    * Dockings can be deleted via 'Delete Docking Log'

"""
from ViewerFramework.VFCommand import CommandGUI
from AutoDockTools.autoanalyzeCommands import menuText,\
checkHasInitializedDockings, hideShowHide, toggleShowHide,\
checkNameStr, ADChooseMacro, ADReadMacro, ADEPDBMol,\
ADSeeSpots, ADShowBindingSite, ADMakeAllGrids, ADGetOutput,\
ADGetAGrid, ADSelectDLG, ADDeleteDLG, ADGetDirDLGs, ADGetDLG,\
ADLoadVinaResult, ADReadVSResult, ClusterDockingChooser, ModelDockingChooser, ADDrawHistogram,\
ADMacroLigandChart, ADDockingChooser, ReadAutoDockStates,\
StatesPlayerWidget, ShowAutoDockStatesBaseCmd, ShowAutoDockStates,\
ShowAutoDockStatesByEnergy, ShowAutoDockPopulation,\
ShowAutoDockStatesHISTOGRAM, ShowAutoDockClusteringStates,\
ReadAutoDockClusteringStates, WriteAutoDockStates,\
WriteAutoDockClustering, MakeAutoDockCLUSTERING,\
MakeAutoDockSubsetCLUSTERING, ADWriteVSResult


ADChooseMacroGUI=CommandGUI()
ADChooseMacroGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['chooseMacro'], cascadeName = menuText['MoleculesMB'])


ADReadMacroGUI=CommandGUI()
ADReadMacroGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['readMacro'], cascadeName = menuText['MoleculesMB'])


ADEPDBMolGUI=CommandGUI()
ADEPDBMolGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['epdbMol'], cascadeName = menuText['GridsMB'])


ADSeeSpotsGUI=CommandGUI()
ADSeeSpotsGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['seeSpots'], cascadeName = menuText['DockingLogMB'])


ADShowBindingSiteGUI=CommandGUI()
ADShowBindingSiteGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['showBindingSite'], cascadeName = menuText['DockingLogMB'])


ADMakeAllGridsGUI=CommandGUI()
ADMakeAllGridsGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
            menuText['showGridsMB'], cascadeName=menuText['GridsMB'])
                

ADGetOutputGUI=CommandGUI()
ADGetOutputGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['getOutputMB'] , cascadeName=menuText['StatesMB'])



ADGetAGridGUI=CommandGUI()
ADGetAGridGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['addGridMB'], cascadeName=menuText['GridsMB'])



ADSelectDLGGUI=CommandGUI()
ADSelectDLGGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['selectDLG'], cascadeName = menuText['DockingLogMB'])


ADDeleteDLGGUI=CommandGUI()
ADDeleteDLGGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'], 
        menuText['deleteDLG'], cascadeName = menuText['DockingLogMB'])


ADGetDirDLGsGUI=CommandGUI()
ADGetDirDLGsGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
        menuText['readDirDLG'], cascadeName = menuText['DockingLogMB'])


ADGetDLGGUI=CommandGUI()
ADGetDLGGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
        menuText['readDLG'], cascadeName = menuText['DockingLogMB'])
###ADGetDLGGUI.menuBarCfg.update({'background':'tan','relief':'sunken'})


ADLoadVinaResultGUI=CommandGUI()
ADLoadVinaResultGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
        menuText['readVinaResult'], cascadeName = menuText['DockingLogMB'])
###ADGetDLGGUI.menuBarCfg.update({'background':'tan','relief':'sunken'})


ADReadVSResultGUI=CommandGUI()
ADReadVSResultGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
        menuText['readVSResult'], cascadeName = menuText['DockingLogMB'])


ADDrawHistogramGUI=CommandGUI()
ADDrawHistogramGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
        menuText['showHistogramMB'], cascadeName=menuText['StatesMB'])



ADMacroLigandChartGUI=CommandGUI()
ADMacroLigandChartGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
            menuText['showChartMB'], cascadeName=menuText['StatesMB'])
            

ADDockingChooserGUI=CommandGUI()
ADDockingChooserGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
        menuText['chooseConfMB'], cascadeName = menuText['StatesMB'])


ReadAutoDockStatesGUI = CommandGUI()
ReadAutoDockStatesGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
        menuText['readStatesMB'],cascadeName=menuText['StatesMB'])


ShowAutoDockStatesGUI = CommandGUI()
ShowAutoDockStatesGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['showStatesMB'],
        cascadeName=menuText['StatesMB'])


ShowAutoDockStatesByEnergyGUI = CommandGUI()
ShowAutoDockStatesByEnergyGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['showStatesByEnergyMB'],
        cascadeName=menuText['StatesMB'])


ShowAutoDockPopulationGUI = CommandGUI()
ShowAutoDockPopulationGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['showPopulationMB'],
        cascadeName=menuText['StatesMB'])



ShowAutoDockStatesHISTOGRAMGUI = CommandGUI()
ShowAutoDockStatesHISTOGRAMGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['showStatesHISTOGRAMMB'], 
    cascadeName=menuText['StatesMB'])



ShowAutoDockStatesCLUSTERINGGUI = CommandGUI()
ShowAutoDockStatesCLUSTERINGGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['showStatesCLUSTERINGMB'], 
    cascadeName=menuText['ClusteringMB'])


ReadAutoDockStatesCLUSTERINGGUI = CommandGUI()
ReadAutoDockStatesCLUSTERINGGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['readStatesCLUSTERINGMB'], 
    cascadeName=menuText['ClusteringMB'])



WriteAutoDockStatesGUI = CommandGUI()
WriteAutoDockStatesGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['writeResultMB'], 
    cascadeName=menuText['StatesMB'])



WriteAutoDockClusteringGUI = CommandGUI()
WriteAutoDockClusteringGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['writeClusteringMB'], 
    cascadeName=menuText['ClusteringMB'])



MakeAutoDockCLUSTERINGGUI = CommandGUI()
MakeAutoDockCLUSTERINGGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['makeCLUSTERINGMB'], 
    cascadeName=menuText['ClusteringMB'])



MakeAutoDockSubsetCLUSTERINGGUI = CommandGUI()
MakeAutoDockSubsetCLUSTERINGGUI.addMenuCommand('AutoTools41Bar', 
    menuText['AnalyzeMB'], menuText['makeSubsetCLUSTERINGMB'], 
    cascadeName=menuText['ClusteringMB'])


ADWriteVSResultGUI=CommandGUI()
ADWriteVSResultGUI.addMenuCommand('AutoTools41Bar', menuText['AnalyzeMB'],
        menuText['writeVSResult'], cascadeName = menuText['DockingLogMB'])



commandList = [
    {'name':'AD41analyze_readDLG','cmd':ADGetDLG(),'gui':ADGetDLGGUI},
    {'name':'AD41analyze_readVinaResult','cmd':ADLoadVinaResult(),'gui':ADLoadVinaResultGUI},
    {'name':'AD41analyze_readVSResult','cmd':ADReadVSResult(),'gui':ADReadVSResultGUI},
    {'name':'AD41analyze_readAllDLGInDirectory','cmd':ADGetDirDLGs(),'gui':ADGetDirDLGsGUI},
    {'name':'AD41analyze_selectDLG','cmd':ADSelectDLG(),'gui':ADSelectDLGGUI},
    {'name':'AD41analyze_deleteDLG','cmd':ADDeleteDLG(),'gui':ADDeleteDLGGUI},
    {'name':'AD41analyze_readMacromolecule','cmd':ADReadMacro(),'gui':ADReadMacroGUI},
    {'name':'AD41analyze_chooseMacromolecule','cmd':ADChooseMacro(),'gui':ADChooseMacroGUI},
    {'name':'AD41analyze_showDockingsAsSpheres','cmd':ADSeeSpots(),'gui':ADSeeSpotsGUI},
    {'name':'AD41analyze_showBindingSite','cmd':ADShowBindingSite(),'gui':ADShowBindingSiteGUI},
    #{'name':'AD41analyze_readStates','cmd':ReadAutoDockStates(),'gui':ReadAutoDockStatesGUI},
    {'name':'AD41analyze_showStates','cmd':ShowAutoDockStates(),'gui':ShowAutoDockStatesGUI},
    {'name':'AD41analyze_showStatesByEnergy','cmd':ShowAutoDockStatesByEnergy(),'gui':ShowAutoDockStatesByEnergyGUI},
    {'name':'AD41analyze_showPopulation','cmd':ShowAutoDockPopulation(),'gui':ShowAutoDockPopulationGUI},
    {'name':'AD41analyze_chooseDockedConformations','cmd':ADDockingChooser(),'gui':ADDockingChooserGUI},
    #{'name':'AD41analyze_showStatesHISTOGRAM','cmd':ShowAutoDockStatesHISTOGRAM(),'gui':ShowAutoDockStatesHISTOGRAMGUI},
    #{'name':'AD41analyze_showResultsOutput','cmd':ADGetOutput(),'gui':ADGetOutputGUI},
    #{'name':'AD41analyze_showHistogram','cmd':ADDrawHistogram(),'gui':ADDrawHistogramGUI},
    #{'name':'AD41analyze_getChart','cmd':ADMacroLigandChart(),'gui':ADMacroLigandChartGUI},
    #{'name':'AD41analyze_writeStates','cmd':WriteAutoDockStates(),'gui':WriteAutoDockStatesGUI},
    {'name':'AD41analyze_showClusteringStates','cmd':ShowAutoDockClusteringStates(),'gui':ShowAutoDockStatesCLUSTERINGGUI},
    #{'name':'AD41analyze_readClusteringStates','cmd':ReadAutoDockClusteringStates(),'gui':ReadAutoDockStatesCLUSTERINGGUI},
    {'name':'AD41analyze_makeClustering','cmd':MakeAutoDockCLUSTERING(),'gui':MakeAutoDockCLUSTERINGGUI},
    {'name':'AD41analyze_makeSubsetClustering','cmd':MakeAutoDockSubsetCLUSTERING(),'gui':MakeAutoDockSubsetCLUSTERINGGUI},
    #{'name':'AD41analyze_writeClustering','cmd':WriteAutoDockClustering(),'gui':WriteAutoDockClusteringGUI},
    {'name':'AD41analyze_writeVSResult','cmd':ADWriteVSResult(),'gui':ADWriteVSResultGUI},
    ]

try:
    from Pmv.Grid import AutoGrid, AutoGridSurfaceGui
    for i in [ #{'name':'AD41analyze_epdbMolecule', 'cmd':ADEPDBMol(), 'gui':ADEPDBMolGUI},
    {'name':'AD41analyze_addExtraGridIsocontour','cmd':ADGetAGrid(),'gui':ADGetAGridGUI}, {'name':'AD41analyze_showGridIsocontours','cmd':ADMakeAllGrids(),'gui':ADMakeAllGridsGUI}]:
        commandList.insert(7,i)
except:
    print 'skipping the isocontour-dependent commands'


def initModule(vf):
    for dict in commandList:
        vf.addCommand(dict['cmd'],dict['name'],dict['gui'])
    #if not hasattr(vf, 'ADanalyze_showHistogram') and hasattr(vf, 'AD41analyze_showHistogram'):
    #    vf.ADanalyze_showHistogram = vf.AD41analyze_showHistogram
    if not hasattr(vf, 'ADanalyze_showDockingsAsSpheres') and hasattr(vf, 'AD41analyze_showDockingsAsSpheres'):
        vf.ADanalyze_showDockingsAsSpheres = vf.AD41analyze_showDockingsAsSpheres
    if not hasattr(vf, 'ADanalyze_showGridIsocontours') and hasattr(vf, 'AD41analyze_showGridIsocontours'):
        vf.ADanalyze_showGridIsocontours = vf.AD41analyze_showGridIsocontours
    if not hasattr(vf, 'ADanalyze_chooseDockedConformations') and hasattr(vf, 'AD41analyze_chooseDockedConformations'):
        vf.ADanalyze_chooseDockedConformations = vf.AD41analyze_chooseDockedConformations
    if not hasattr(vf, 'ADanalyze_readDLG') and hasattr(vf, 'AD41analyze_readDLG'):
        vf.ADanalyze_readDLG = vf.AD41analyze_readDLG
    if not hasattr(vf, 'ADanalyze_selectDLG') and hasattr(vf, 'AD41analyze_selectDLG'):
        vf.ADanalyze_selectDLG = vf.AD41analyze_selectDLG
    if not hasattr(vf, 'ADanalyze_makeSubsetClustering') and hasattr(vf, 'AD41analyze_makeSubsetClustering'):
        vf.ADanalyze_makeSubsetClustering = vf.AD41analyze_makeSubsetClustering


    if hasattr(vf, 'GUI') and 'AutoTools41Bar' in vf.GUI.menuBars.keys():
        for item in vf.GUI.menuBars['AutoTools41Bar'].menubuttons.values():
            item.configure(background = 'tan')
        if not hasattr(vf.GUI, 'adtBar'):
            vf.GUI.adtBar = vf.GUI.menuBars['AutoTools41Bar']
            vf.GUI.adtFrame = vf.GUI.adtBar.menubuttons.values()[0].master
            








#
#
#  $Id: test_AutoLigandCommand.py,v 1.4 2011/06/13 20:04:05 annao Exp $
#
#

import unittest, glob, os, sys
from string import strip, find, split
import time
from MolKit.molecule import Atom

mv = None
ct = 0
totalCt = 1


class AutoLigandCommand_BaseTests(unittest.TestCase):
    """
    setUp + tearDown form a fixture: working environment for the testing code
    """
    
        
    def startViewer(self):
        global mv
        #print 'in test_AD startViewer'
        if mv is None:
            from MolKit import Read
            import Tkinter
            from Pmv.moleculeViewer import MoleculeViewer
            mv = MoleculeViewer(trapExceptions=False)
            mv.loadModule('AutoLigandCommand', 'AutoDockTools')
            mv.loadModule('deleteCommands', 'Pmv')
            mv.loadModule('selectionCommands', 'Pmv')
            #change warningMsg format
            mv.setUserPreference(('warningMsgFormat', 'printed'), log = 0)
        self.mv = mv


    def setUp(self):
        """
        clean-up
        """
        if not hasattr(self, 'mv'):
            self.startViewer()
        for m in self.mv.Mols:
            self.mv.deleteMol(m)


    def tearDown(self):
        """
        clean-up
        """
        #print 'in flex tearDown'
        global ct, totalCt
        #reset flexDict object
        self.mv.flexDict = {}
        #delete any molecules left due to errors
        for m in self.mv.Mols:
            self.mv.deleteMol(m)
        ct = ct + 1
        #print 'ct =', ct
        if ct==totalCt:
            print 'destroying mv'
            self.mv.Exit(0)
            del self.mv       
    
        
from mglutil.gui.InputForm.Tk.gui import InputFormDescr
class AutoLigandCommandTests(AutoLigandCommand_BaseTests):
    
    
    def test_gui(self):
        """test_gui: check that the GUI is working
        """
        self.mv.GUI.ROOT.after(2000, self.envoke)
        self.mv.AutoLigandCommand.guiCallback()
        ans = 'l'
        while ans != 'normal':
            ans = self.mv.AutoLigandCommand.cmd.ok.configure()['state'][-1]
            self.mv.GUI.ROOT.update()

        
    def envoke(self):
        self.mv.AutoLigandCommand.ifd.entryByName['FileBaseName']['widget'].selectitem('AG4_hsg1')
        self.mv.AutoLigandCommand.selectGrid('AG4_hsg1')
        self.mv.AutoLigandCommand.ifd.form.OK_cb()
        #self.mv.GUI.ROOT.update()
        #self.mv.AutoLigandCommand.ifd.form.root.destroy()
#        self.mv.GUI.ROOT.after(10, self.check)

        
    def check(self):
        self.mv.GUI.ROOT.update()
            
if __name__ == '__main__':
    unittest.main()



#
# Last modified on Mon Mar  4 14:35:36 PST 2002 by lindy
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/ResultParser.py,v 1.3 2009/01/09 19:53:49 rhuey Exp $
#




class ResultParser:
    """Base class of result parsers. Supply your own parseline
    function which appends a conformation dictionary to self.clist
    """
    def __init__(self):
        self.clist = []

    # add more keywords in subclass if you like 
    keywords = [
        'cluster',            # number of cluster
        'cluster_rank',       # rank within cluster
        'rmsd_ref',           # distance to reference structure
        'rmsd_seed',          # distance to lowest energy conf. in cluster
        'binding_energy',     # estimated free energy of binding
        'docking_energy',     # final docked energy
        'internal_energy',
        'trn_x',              # translation x, y, z
        'trn_y',
        'trn_z',
        'qtn_nx',             # quaternion unit vector x, y, z
        'qtn_ny',
        'qtn_nz',
        'qtn_ang_deg',        # quaternion rotation angle
        'num_torsions',
        'torsion_values',
        'rseed1',             # the random number seeds for this conformation
        'rseed2',
        ]

    def parse(self, filename):
        """
        """
        file_ptr = open(filename)
        
        self.clist = []
        for line in file_ptr.readlines():
            self.parseline(line)
        file_ptr.close()

        self.filename = filename
        
        return self.clist


    def parseline(self, line):
        """over ride me"""
        pass
    
